@@ -11,5 +11,7 @@ oIFS=$IFS
 IFS=" 
 "
 
-$QMAKE $C
+test -z "$EXTRA_CXXFLAGS" || FLAGS="QMAKE_CXXFLAGS += $EXTRA_CXXFLAGS"
+
+$QMAKE "$FLAGS" $C
 
