@@ -28,18 +28,25 @@
 
 #include "BaseObjectGroup.h"
 
+namespace fwcompiler {
 
-class IOSObjectGroup : public BaseObjectGroup {
+    class IOSObjectGroup : public BaseObjectGroup
+    {
     
-    public:
-    IOSObjectGroup(object_group_type _gt=UNKNOWN) : BaseObjectGroup(_gt) { }
-    virtual ~IOSObjectGroup() {};
-    DECLARE_FWOBJECT_SUBTYPE(IOSObjectGroup);
+public:
+        IOSObjectGroup() : BaseObjectGroup() { }
+        virtual ~IOSObjectGroup() {};
+        DECLARE_FWOBJECT_SUBTYPE(IOSObjectGroup);
 
-    virtual std::string getObjectGroupClass();
-    virtual std::string getObjectGroupHeader();
-    virtual std::string toString() throw(libfwbuilder::FWException);
+        virtual std::string getObjectGroupClass();
+        virtual std::string getObjectGroupHeader();
+        virtual std::string getObjectGroupFooter();
+
+        virtual QString groupMemberToString(
+            libfwbuilder::FWObject *obj, NamedObjectsManager *named_obj_manager)
+            throw(libfwbuilder::FWException);
     
-};
+    };
+}
 
 #endif
