@@ -26,32 +26,22 @@
 #include "config.h"
 
 #include "PolicyCompiler_iosacl.h"
+#include "NamedObjectsAndGroupsSupport.h"
 
+#include "fwbuilder/AddressTable.h"
 #include "fwbuilder/FWObjectDatabase.h"
-#include "fwbuilder/RuleElement.h"
-#include "fwbuilder/IPService.h"
 #include "fwbuilder/ICMPService.h"
+#include "fwbuilder/IPService.h"
+#include "fwbuilder/Interface.h"
+#include "fwbuilder/Library.h"
+#include "fwbuilder/Management.h"
+#include "fwbuilder/Network.h"
+#include "fwbuilder/ObjectMirror.h"
+#include "fwbuilder/Policy.h"
+#include "fwbuilder/Resources.h"
+#include "fwbuilder/RuleElement.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
-#include "fwbuilder/Network.h"
-#include "fwbuilder/Policy.h"
-#include "fwbuilder/Interface.h"
-#include "fwbuilder/Management.h"
-#include "fwbuilder/Resources.h"
-#include "fwbuilder/AddressTable.h"
-#include "fwbuilder/ObjectMirror.h"
-
-#include <iostream>
-#if __GNUC__ > 3 || \
-    (__GNUC__ == 3 && (__GNUC_MINOR__ > 2 || (__GNUC_MINOR__ == 2 ) ) ) || \
-     _MSC_VER
-#  include <streambuf>
-#else
-#  include <streambuf.h>
-#endif
-#include <iomanip>
-#include <algorithm>
-#include <functional>
 
 #include <assert.h>
 
@@ -85,44 +75,14 @@ int PolicyCompiler_iosacl::prolog()
         "use_acl_remarks",
         fw->getOptionsObject()->getBool("iosacl_use_acl_remarks"));
 
-    object_groups = new Group();
-    dbcopy->add( object_groups );
+    // object_groups = new Group();
+    // persistent_objects->add( object_groups );
 
     setAllNetworkZonesToNone();
 
     return PolicyCompiler::prolog();
 }
 
-void PolicyCompiler_iosacl::addDefaultPolicyRule()
-{
-    PolicyCompiler_cisco::addDefaultPolicyRule();
-
-/*
- * PolicyCompiler_cisco::addDefaultPolicyRule() adds a rule to permit
- * backup ssh access to the firewall. Since IOS ACL are stateless, we
- * need to add another rule to permit reply packets.
- */
-    if ( getCachedFwOpt()->getBool("mgmt_ssh") &&
-         !getCachedFwOpt()->getStr("mgmt_addr").empty() )
-    {
-        TCPService *ssh_rev = dbcopy->createTCPService();
-        ssh_rev->setSrcRangeStart(22);
-        ssh_rev->setSrcRangeEnd(22);
-        dbcopy->add(ssh_rev, false);
-
-        Network *mgmt_workstation = dbcopy->createNetwork();
-        mgmt_workstation->setAddressNetmask(
-            getCachedFwOpt()->getStr("mgmt_addr"));
-
-        dbcopy->add(mgmt_workstation, false);
-
-        PolicyCompiler::addMgmtRule(
-            fw, mgmt_workstation, ssh_rev,
-            NULL, PolicyRule::Outbound, PolicyRule::Accept,
-            "backup ssh access rule (out)");
-    }
-}
-
 bool PolicyCompiler_iosacl::checkForDynamicInterface::findDynamicInterface(
     PolicyRule *rule, RuleElement *rel)
 {
@@ -208,7 +168,8 @@ bool PolicyCompiler_iosacl::mirrorRule::processNext()
             {
                 Service *nobj = mirror.getMirroredService(
                     Service::cast(FWReference::getObject(*i1)));
-                compiler->dbcopy->add(nobj, false);
+                if (nobj->getParent() == NULL)
+                    compiler->persistent_objects->add(nobj, false);
                 nsrv->addRef(nobj);
             }
         }
@@ -304,188 +265,179 @@ void PolicyCompiler_iosacl::compile()
     bool supports_object_groups = XMLTools::version_compare(version, "12.4")>=0 &&
         fw->getOptionsObject()->getBool("iosacl_use_object_groups") && ! ipv6;
 
-    try 
+    string vers = fw->getStr("version");
+    string platform = fw->getStr("platform");
+
+    Compiler::compile();
+
+    if ( fw->getOptionsObject()->getBool ("check_shading") &&
+         ! inSingleRuleCompileMode())
     {
-        string vers = fw->getStr("version");
-        string platform = fw->getStr("platform");
+        add( new Begin("Detecting rule shadowing"               ) );
+        add( new printTotalNumberOfRules());
 
-	Compiler::compile();
+        add( new ItfNegation("process negation in Itf"  ) );
+        add( new InterfacePolicyRules(
+                 "process interface policy rules and store interface ids"));
 
-	addDefaultPolicyRule();
+        add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+        add( new recursiveGroupsInDst("check for recursive groups in DST"));
+        add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
 
-        if ( fw->getOptionsObject()->getBool ("check_shading") &&
-             ! inSingleRuleCompileMode())
-        {
-            add( new Begin("Detecting rule shadowing"               ) );
-            add( new printTotalNumberOfRules());
-
-            add( new ItfNegation("process negation in Itf"  ) );
-            add( new InterfacePolicyRules(
-                     "process interface policy rules and store interface ids"));
-
-            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
-            add( new recursiveGroupsInDst("check for recursive groups in DST"));
-            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
-
-            add( new ExpandGroups("expand groups"));
-            add( new dropRuleWithEmptyRE(
-                     "drop rules with empty rule elements"));
-            add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC"));
-            add( new eliminateDuplicatesInDST("eliminate duplicates in DST"));
-            add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV"));
-            add( new ExpandMultipleAddressesInSrc(
-                     "expand objects with multiple addresses in SRC" ) );
-            add( new ExpandMultipleAddressesInDst(
-                     "expand objects with multiple addresses in DST" ) );
-            add( new dropRuleWithEmptyRE(
-                     "drop rules with empty rule elements"));
-
-            add( new mirrorRule("Add mirrored rules"));
-
-            add( new ConvertToAtomic("convert to atomic rules"       ) );
-
-            add( new checkForObjectsWithErrors(
-                     "check if we have objects with errors in rule elements"));
-
-            add( new DetectShadowing("Detect shadowing"              ) );
-            add( new simplePrintProgress() );
-
-            runRuleProcessors();
-            deleteRuleProcessors();
-        }
-
-
-        add( new Begin (" Start processing rules" ) );
-        add( new printTotalNumberOfRules ( ) );
-
-        add( new singleRuleFilter());
-
-        add( new recursiveGroupsInSrc( "check for recursive groups in SRC" ) );
-        add( new recursiveGroupsInDst( "check for recursive groups in DST" ) );
-        add( new recursiveGroupsInSrv( "check for recursive groups in SRV" ) );
-
-        add( new emptyGroupsInSrc( "check for empty groups in SRC" ) );
-        add( new emptyGroupsInDst( "check for empty groups in DST" ) );
-        add( new emptyGroupsInSrv( "check for empty groups in SRV" ) );
-
-        add( new ExpandGroups ("expand groups" ) );
+        add( new ExpandGroups("expand groups"));
         add( new dropRuleWithEmptyRE(
                  "drop rules with empty rule elements"));
-        add( new eliminateDuplicatesInSRC( "eliminate duplicates in SRC" ) );
-        add( new eliminateDuplicatesInDST( "eliminate duplicates in DST" ) );
-        add( new eliminateDuplicatesInSRV( "eliminate duplicates in SRV" ) );
-
-        add( new processMultiAddressObjectsInSrc(
-                 "process MultiAddress objects in Src") );
-        add( new processMultiAddressObjectsInDst(
-                 "process MultiAddress objects in Dst") );
-
-        add( new expandGroupsInItf("expand groups in Interface" ));
-        add( new replaceClusterInterfaceInItf(
-                 "replace cluster interfaces with member interfaces in the Interface rule element"));
-
-        add( new ItfNegation( "process negation in Itf" ) );
-        add( new InterfacePolicyRules(
-                 "process interface policy rules and store interface ids") );
-
-        add( new splitServices ("split rules with different protocols" ) );
-
+        add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC"));
+        add( new eliminateDuplicatesInDST("eliminate duplicates in DST"));
+        add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV"));
         add( new ExpandMultipleAddressesInSrc(
                  "expand objects with multiple addresses in SRC" ) );
-        add( new MACFiltering ("check for MAC address filtering" ) );
-//        add( new splitByNetworkZonesForSrc ("split rule if objects in Src belong to different network zones " ) );
-//        add( new replaceFWinDSTPolicy ("replace fw with its interface in DST in global policy rules") );
-
         add( new ExpandMultipleAddressesInDst(
                  "expand objects with multiple addresses in DST" ) );
-        add( new MACFiltering(
-                 "check for MAC address filtering" ) );
-        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
-
-//        add( new splitByNetworkZonesForDst ("split rule if objects in Dst belong to different network zones " ) );
-
-        if (ipv6)
-            add( new DropIPv4Rules("drop ipv4 rules"));
-        else
-            add( new DropIPv6Rules("drop ipv6 rules"));
-        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
-
-        add( new checkForUnnumbered("check for unnumbered interfaces"));
-
-        if ( ! supports_object_groups)
-            add( new addressRanges("process address ranges"));
+        add( new dropRuleWithEmptyRE(
+                 "drop rules with empty rule elements"));
 
         add( new mirrorRule("Add mirrored rules"));
 
-        add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
-
-        add( new setInterfaceAndDirectionBySrc(
-    "Set interface and direction for rules with interface 'all' using SRC"));
-        add( new setInterfaceAndDirectionByDst(
-    "Set interface and direction for rules with interface 'all' using DST"));
-        add( new setInterfaceAndDirectionIfInterfaceSet(
-                 "Set direction for rules with interface not 'all'"));
-
-        add( new specialCaseWithDynInterface(
-                 "check for a special cases with dynamic interface" ) );
-
-        // first arg is true because we use "ip access-list" for IOS.
-        add( new pickACL( true, "assign ACLs" ) );
-
-        add( new SpecialServices( "check for special services" ) );
-        add( new CheckForUnsupportedUserService("check for user service") );
-
-        add( new checkForZeroAddr(    "check for zero addresses" ) );
-        add( new checkForDynamicInterface("check for dynamic interfaces" ) );
-
-        /* remove redundant objects only after all splits has been
-         * done, right before object groups are created
-         */
-        add( new removeRedundantAddressesFromSrc(
-                 "remove redundant addresses from Src") );
-        add( new removeRedundantAddressesFromDst(
-                 "remove redundant addresses from Dst") );
+        add( new ConvertToAtomic("convert to atomic rules"       ) );
 
         add( new checkForObjectsWithErrors(
                  "check if we have objects with errors in rule elements"));
 
-        if (supports_object_groups)
-        {
-            // "object-group service" does not seem to support
-            // matching of tcp flags and "established". Need to
-            // separate objects using these into separate rules to avoid
-            // object-group
-
-            add( new splitTCPServiceWithFlags(
-                     "separate TCP service with tcp flags"));
-
-            add( new CreateObjectGroupsForSrc("create object groups for Src"));
-            add( new CreateObjectGroupsForDst("create object groups for Dst"));
-            add( new CreateObjectGroupsForSrv("create object groups for Srv"));
-        } else
-        {
-            add( new ConvertToAtomic ("convert to atomic rules" ) );
-        }
-
-        add( new simplePrintProgress());
-        add( new createNewCompilerPass("Creating object groups and ACLs"));
-
-        add( new printClearCommands("clear commands for object-groups and ACLs"));
-        add( new printObjectGroups("generate code for object groups"));
-
-        // This processor prints each ACL separately in one block.
-        // It adds comments inside to denote original rules.
-        //
-        add( new PrintCompleteACLs("Print ACLs"));
-        add( new simplePrintProgress());
+        add( new DetectShadowing("Detect shadowing"              ) );
+        add( new simplePrintProgress() );
 
         runRuleProcessors();
-
-    } catch (FWException &ex)
-    {
-	error(ex.toString());
-        exit(1);
+        deleteRuleProcessors();
     }
+
+
+    add( new Begin (" Start processing rules" ) );
+    add( new printTotalNumberOfRules ( ) );
+
+    add( new singleRuleFilter());
+
+    add( new recursiveGroupsInSrc( "check for recursive groups in SRC" ) );
+    add( new recursiveGroupsInDst( "check for recursive groups in DST" ) );
+    add( new recursiveGroupsInSrv( "check for recursive groups in SRV" ) );
+
+    add( new emptyGroupsInSrc( "check for empty groups in SRC" ) );
+    add( new emptyGroupsInDst( "check for empty groups in DST" ) );
+    add( new emptyGroupsInSrv( "check for empty groups in SRV" ) );
+
+    add( new ExpandGroups ("expand groups" ) );
+    add( new dropRuleWithEmptyRE(
+             "drop rules with empty rule elements"));
+    add( new eliminateDuplicatesInSRC( "eliminate duplicates in SRC" ) );
+    add( new eliminateDuplicatesInDST( "eliminate duplicates in DST" ) );
+    add( new eliminateDuplicatesInSRV( "eliminate duplicates in SRV" ) );
+
+    add( new processMultiAddressObjectsInSrc(
+             "process MultiAddress objects in Src") );
+    add( new processMultiAddressObjectsInDst(
+             "process MultiAddress objects in Dst") );
+
+    add( new expandGroupsInItf("expand groups in Interface" ));
+    add( new replaceClusterInterfaceInItf(
+             "replace cluster interfaces with member interfaces in the Interface rule element"));
+
+    add( new ItfNegation( "process negation in Itf" ) );
+    add( new InterfacePolicyRules(
+             "process interface policy rules and store interface ids") );
+
+    add( new groupServicesByProtocol ("split rules with different protocols" ) );
+
+    add( new ExpandMultipleAddressesInSrc(
+             "expand objects with multiple addresses in SRC" ) );
+    add( new MACFiltering ("check for MAC address filtering" ) );
+//        add( new splitByNetworkZonesForSrc ("split rule if objects in Src belong to different network zones " ) );
+//        add( new replaceFWinDSTPolicy ("replace fw with its interface in DST in global policy rules") );
+
+    add( new ExpandMultipleAddressesInDst(
+             "expand objects with multiple addresses in DST" ) );
+    add( new MACFiltering(
+             "check for MAC address filtering" ) );
+    add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
+
+//        add( new splitByNetworkZonesForDst ("split rule if objects in Dst belong to different network zones " ) );
+
+    if (ipv6)
+        add( new DropIPv4Rules("drop ipv4 rules"));
+    else
+        add( new DropIPv6Rules("drop ipv6 rules"));
+    add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
+
+    add( new checkForUnnumbered("check for unnumbered interfaces"));
+
+    if ( ! supports_object_groups)
+        add( new addressRanges("process address ranges"));
+
+    add( new mirrorRule("Add mirrored rules"));
+
+    add( new dropRuleWithEmptyRE("drop rules with empty rule elements"));
+
+    add( new setInterfaceAndDirectionBySrc(
+             "Set interface and direction for rules with interface 'all' using SRC"));
+    add( new setInterfaceAndDirectionByDst(
+             "Set interface and direction for rules with interface 'all' using DST"));
+    add( new setInterfaceAndDirectionIfInterfaceSet(
+             "Set direction for rules with interface not 'all'"));
+
+    add( new specialCaseWithDynInterface(
+             "check for a special cases with dynamic interface" ) );
+
+    // first arg is true because we use "ip access-list" for IOS.
+    add( new pickACL( true, "assign ACLs" ) );
+
+    add( new SpecialServices( "check for special services" ) );
+    add( new CheckForUnsupportedUserService("check for user service") );
+
+    add( new checkForZeroAddr(    "check for zero addresses" ) );
+    add( new checkForDynamicInterface("check for dynamic interfaces" ) );
+
+    /* remove redundant objects only after all splits has been
+     * done, right before object groups are created
+     */
+    add( new removeRedundantAddressesFromSrc(
+             "remove redundant addresses from Src") );
+    add( new removeRedundantAddressesFromDst(
+             "remove redundant addresses from Dst") );
+
+    add( new checkForObjectsWithErrors(
+             "check if we have objects with errors in rule elements"));
+
+    if (supports_object_groups)
+    {
+        // "object-group service" does not seem to support
+        // matching of tcp flags and "established". Need to
+        // separate objects using these into separate rules to avoid
+        // object-group
+
+        add( new splitTCPServiceWithFlags(
+                 "separate TCP service with tcp flags"));
+
+        add( new CreateObjectGroupsForSrc("create object groups for Src",
+                                          named_objects_manager));
+        add( new CreateObjectGroupsForDst("create object groups for Dst",
+                                          named_objects_manager));
+        add( new CreateObjectGroupsForSrv("create object groups for Srv",
+                                          named_objects_manager));
+    } else
+    {
+        add( new ConvertToAtomic ("convert to atomic rules" ) );
+    }
+
+    add( new simplePrintProgress());
+    add( new createNewCompilerPass("Creating object groups and ACLs"));
+
+    // This processor prints each ACL separately in one block.
+    // It adds comments inside to denote original rules.
+    //
+    add( new PrintCompleteACLs("Print ACLs"));
+    add( new simplePrintProgress());
+
+    runRuleProcessors();
+
 }
 
 string PolicyCompiler_iosacl::printAccessGroupCmd(ciscoACL *acl, bool neg)
@@ -534,3 +486,34 @@ string PolicyCompiler_iosacl::getAccessGroupCommandForAddressFamily(bool ipv6)
     if (ipv6) return "traffic-filter";
     return "access-group";
 }
+
+string PolicyCompiler_iosacl::printClearCommands()
+{
+    ostringstream output;
+
+    string version = fw->getStr("version");
+    string platform = fw->getStr("platform");
+
+    string xml_element = "clear_ip_acl";
+    if (ipv6) xml_element = "clear_ipv6_acl";
+
+    string clearACLCmd = Resources::platform_res[platform]->getResourceStr(
+        string("/FWBuilderResources/Target/options/") +
+        "version_" + version + "/iosacl_commands/" + xml_element);
+
+    assert( !clearACLCmd.empty());
+
+    // No need to output "clear" commands in single rule compile mode
+    if ( fw->getOptionsObject()->getBool("iosacl_acl_basic") ||
+         fw->getOptionsObject()->getBool("iosacl_acl_substitution"))
+    {
+        for (map<string,ciscoACL*>::iterator i=acls.begin(); i!=acls.end(); ++i)
+        {
+            ciscoACL *acl = (*i).second;
+            output << clearACLCmd << " " << acl->workName() << endl;
+        }
+    }
+
+    return output.str();
+}
+
