@@ -25,6 +25,8 @@
 
 #include "PolicyCompiler_pix.h"
 #include "PIXObjectGroup.h"
+#include "NamedObjectsManager.h"
+#include "PortRangeConverter.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/AddressRange.h"
@@ -44,13 +46,6 @@
 #include "fwbuilder/Resources.h"
 
 #include <iostream>
-#if __GNUC__ > 3 || \
-    (__GNUC__ == 3 && (__GNUC_MINOR__ > 2 || (__GNUC_MINOR__ == 2 ) ) ) || \
-    _MSC_VER
-#  include <streambuf>
-#else
-#  include <streambuf.h>
-#endif
 #include <iomanip>
 #include <fstream>
 #include <sstream>
@@ -59,66 +54,14 @@
 
 #include <assert.h>
 
+#include <QStringList>
+
+
 using namespace libfwbuilder;
 using namespace fwcompiler;
 using namespace std;
 
 
-bool PolicyCompiler_pix::printClearCommands::processNext()
-{
-    PolicyCompiler_pix *pix_comp=dynamic_cast<PolicyCompiler_pix*>(compiler);
-    string vers = compiler->fw->getStr("version");
-    string platform = compiler->fw->getStr("platform");
-    string clearACLcmd = Resources::platform_res[platform]->getResourceStr(
-        string("/FWBuilderResources/Target/options/")+
-        "version_"+vers+"/pix_commands/clear_acl");
-    string clearOGcmd = Resources::platform_res[platform]->getResourceStr(
-        string("/FWBuilderResources/Target/options/")+
-        "version_"+vers+"/pix_commands/clear_og");
-    string clearICMPcmd = Resources::platform_res[platform]->getResourceStr(
-        string("/FWBuilderResources/Target/options/")+
-        "version_"+vers+"/pix_commands/clear_icmp");
-    string clearTelnetcmd = Resources::platform_res[platform]->getResourceStr(
-        string("/FWBuilderResources/Target/options/")+
-        "version_"+vers+"/pix_commands/clear_telnet");
-
-
-    slurp();
-    if (tmp_queue.size()==0) return false;
-
-    if (!compiler->inSingleRuleCompileMode())
-    {
-        // No need to output "clear" commands in single rule compile mode
-
-        if ( compiler->fw->getOptionsObject()->getBool("pix_acl_basic") )
-        {
-            compiler->output << clearACLcmd << endl;
-            compiler->output << clearOGcmd  << endl;
-        }
-
-        if (compiler->fw->getOptionsObject()->getBool("pix_acl_substitution"))
-        {
-            for (map<string,ciscoACL*>::iterator i=pix_comp->acls.begin();
-                 i!=pix_comp->acls.end(); ++i) 
-            {
-                ciscoACL *acl=(*i).second;
-                compiler->output << clearACLcmd << " " << acl->workName() << endl;
-            }
-            compiler->output << clearOGcmd << endl;
-            compiler->output << endl;
-        }
-
-        if ( !compiler->fw->getOptionsObject()->getBool("pix_acl_no_clear") )
-        {
-            compiler->output << clearICMPcmd    << endl;
-            compiler->output << clearTelnetcmd  << endl;
-        }
-    }
-
-    return true;
-}
-
-
 string PolicyCompiler_pix::PrintRule::_printAction(PolicyRule *rule)
 {
     ostringstream  str;
@@ -144,75 +87,74 @@ string PolicyCompiler_pix::PrintRule::_printACL(PolicyRule *rule)
 
 string PolicyCompiler_pix::PrintRule::_printLog(PolicyRule *rule)
 {
-    string platform=compiler->fw->getStr("platform");
-    string vers=compiler->fw->getStr("version");
+    string platform = compiler->fw->getStr("platform");
+    string vers = compiler->fw->getStr("version");
     if (platform=="pix" && (vers=="6.1" || vers=="6.2")) return "";
 
 //    PolicyCompiler_pix *pix_comp=dynamic_cast<PolicyCompiler_pix*>(compiler);
     FWOptions  *ruleopt =rule->getOptionsObject();
-    ostringstream  str;
+    QStringList str;
 
     if (ruleopt->getBool("disable_logging_for_this_rule"))
         return "log disable ";
 
     if (rule->getLogging())
     {
-        string level=ruleopt->getStr("log_level");
-        int    logint=ruleopt->getInt("log_interval");
+        string level = ruleopt->getStr("log_level");
+        int    logint = ruleopt->getInt("log_interval");
 /*
  *  PIX always adds logging interval in "show * access-list" command,
  *  so we should always add it, too. Otherwise ACL lines look
  *  different when diff is generated.
  */
         if (logint<=0)
-            logint=Resources::platform_res[platform]->getResourceInt(
-                string("/FWBuilderResources/Target/options/")+
-                "version_"+compiler->fw->getStr("version")+
+            logint = Resources::platform_res[platform]->getResourceInt(
+                string("/FWBuilderResources/Target/options/") +
+                "version_" + compiler->fw->getStr("version") +
                 "/pix_default_logint");
 
-        if (level.empty()) level= compiler->fw->getOptionsObject()->getStr("pix_logging_trap_level");
+        if (level.empty())
+            level = compiler->fw->getOptionsObject()->getStr(
+                "pix_logging_trap_level");
 
-        if (!level.empty())
+        if (level.empty())
+            level = Resources::platform_res[platform]->getResourceStr(
+                string("/FWBuilderResources/Target/options/") +
+                "version_" + compiler->fw->getStr("version") +
+                "/pix_default_loglevel");
+
+        if (level=="alert")   level = "1";
+        if (level=="crit")    level = "2";
+        if (level=="error")   level = "3";
+        if (level=="warning") level = "4";
+        if (level=="notice")  level = "5";
+        if (level=="info")    level = "6";
+        if (level=="debug")   level = "7";
+
+        str << "log" << level.c_str();
+
+        if (logint>0 || platform=="pix") // can't use "interval 0" on fwsm
         {
-            if (level=="alert")   level="1";
-            if (level=="crit")    level="2";
-            if (level=="error")   level="3";
-            if (level=="warning") level="4";
-            if (level=="notice")  level="5";
-            if (level=="info")    level="6";
-            if (level=="debug")   level="7";
-            str << "log " << level << " ";
-            if (logint>0 || platform=="pix") // can't use "interval 0" on fwsm
-                str << "interval " << logint << " ";
+            str << "interval" << QString().setNum(logint);
         }
     }
-    return str.str();
+    return str.join(" ").toStdString();
+}
+
+string PolicyCompiler_pix::PrintRule::_printPortRangeOp(int rs, int re)
+{
+    return PortRangeConverter(rs, re).toString();
 }
 
 string PolicyCompiler_pix::PrintRule::_printSrcService(Service *srv)
 {
-    ostringstream  str;
-
     if (TCPService::isA(srv) || UDPService::isA(srv)) 
     {
-	int rs=TCPUDPService::cast(srv)->getSrcRangeStart();
-	int re=TCPUDPService::cast(srv)->getSrcRangeEnd();
-
-        if (rs<0) rs=0;
-        if (re<0) re=0;
-
-	if (rs>0 || re>0)
-        {
-	    if (rs==re)  str << "eq " << rs << " ";
-	    else
-		if (rs==0 && re!=0)      str << "lt " << re << " ";
-		else
-		    if (rs!=0 && re==65535)  str << "gt " << rs << " ";
-		    else
-			str << "range " << rs << " " << re << " ";
-	}
+	int rs = TCPUDPService::cast(srv)->getSrcRangeStart();
+	int re = TCPUDPService::cast(srv)->getSrcRangeEnd();
+        return _printPortRangeOp(rs, re);
     }
-    return str.str();
+    return "";
 }
 
 string PolicyCompiler_pix::PrintRule::_printDstService(Service *srv)
@@ -223,23 +165,19 @@ string PolicyCompiler_pix::PrintRule::_printDstService(Service *srv)
     {
 	int rs=TCPUDPService::cast(srv)->getDstRangeStart();
 	int re=TCPUDPService::cast(srv)->getDstRangeEnd();
-
-        if (rs<0) rs=0;
-        if (re<0) re=0;
-
-	if (rs>0 || re>0)
-        {
-	    if (rs==re)  str << "eq " << rs << " ";
-	    else
-		if (rs==0 && re!=0)      str << "lt " << re << " ";
-		else
-		    if (rs!=0 && re==65535)  str << "gt " << rs << " ";
-		    else
-			str << "range " << rs << " " << re << " ";
-	}
+        str <<  _printPortRangeOp(rs, re);
     }
+
     if (ICMPService::isA(srv) && srv->getInt("type")!=-1)
-	    str << srv->getStr("type") << " ";
+    {
+        str << srv->getStr("type") << " ";
+    }
+
+    if (CustomService::isA(srv)) 
+    {
+	str << CustomService::cast(srv)->getCodeForPlatform(
+            compiler->myPlatformName() ) << " ";
+    }
 
     const IPService *ip_srv = IPService::constcast(srv);
     if (ip_srv && ip_srv->hasIpOptions())
@@ -303,7 +241,7 @@ string PolicyCompiler_pix::PrintRule::_printAddr(libfwbuilder::Address  *o)
 bool PolicyCompiler_pix::PrintRule::suppressDuplicateICMPCommands(const string &cmd)
 {
     list<string>::iterator i;
-    i=std::find(seen_icmp_commands.begin(),seen_icmp_commands.end(),cmd);
+    i = std::find(seen_icmp_commands.begin(), seen_icmp_commands.end(), cmd);
     if (i!=seen_icmp_commands.end()) return true;
     seen_icmp_commands.push_back(cmd);
     return false;
@@ -312,26 +250,25 @@ bool PolicyCompiler_pix::PrintRule::suppressDuplicateICMPCommands(const string &
 string PolicyCompiler_pix::PrintRule::_printICMPCommand(PolicyRule *rule)
 {
     ostringstream  str;
+    Address *src = compiler->getFirstSrc(rule);
+    RuleElementSrv *srvrel = rule->getSrv();
+    FWObject *srv = srvrel->front();
+    if (FWReference::cast(srv)!=NULL) srv = FWReference::cast(srv)->getPointer();
 
-    Address *src   =compiler->getFirstSrc(rule);
+    // Interface *rule_iface =
+    //     Interface::cast(compiler->dbcopy->findInIndex(rule->getInterfaceId()));
 
-    RuleElementSrv *srvrel=rule->getSrv();
-    FWObject       *srv=srvrel->front();
-    if (FWReference::cast(srv)!=NULL) srv=FWReference::cast(srv)->getPointer();
+    RuleElementItf *intf_re = rule->getItf();
+    Interface *rule_iface = Interface::cast(
+        FWObjectReference::getObject(intf_re->front()));
 
-    Interface *rule_iface = Interface::cast(compiler->dbcopy->findInIndex(rule->getInterfaceId()));
     assert(rule_iface);
 
-    if ( PIXObjectGroup::cast(srv)!=NULL && 
-         PIXObjectGroup::cast(srv)->getObjectGroupType()==BaseObjectGroup::ICMP_TYPE)
+    if (PIXObjectGroup::cast(srv)!=NULL)
     {
         for (FWObject::iterator i1=srv->begin(); i1!=srv->end(); ++i1)
         {
-            FWObject *o   = *i1;
-            FWObject *obj = o;
-            if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
-
-            ICMPService *s=ICMPService::cast(obj);
+            ICMPService *s = ICMPService::cast(FWReference::getObject(*i1));
             assert(s!=NULL);
 
             ostringstream  str1;
@@ -356,77 +293,67 @@ string PolicyCompiler_pix::PrintRule::_printICMPCommand(PolicyRule *rule)
         str << " ";
         str << rule_iface->getLabel();
         str << endl;
+
         if ( ! suppressDuplicateICMPCommands(str.str()))  return str.str();
     }
 
     return "";
 }
 
-string    PolicyCompiler_pix::PrintRule::_printSSHTelnetCommand(PolicyRule *rule)
+string PolicyCompiler_pix::PrintRule::_printSSHTelnetCommand(PolicyRule *rule)
 {
-//    Helper helper(this);
-
     ostringstream  str;
     int port;
 
-    RuleElementSrc *rel=rule->getSrc();
-    Service        *srv=compiler->getFirstSrv(rule);
+    RuleElementSrc *rel = rule->getSrc();
+    Service *srv = compiler->getFirstSrv(rule);
 
-    Interface *rule_iface = Interface::cast(compiler->dbcopy->findInIndex(rule->getInterfaceId()));
+    RuleElementItf *intf_re = rule->getItf();
+    Interface *rule_iface = Interface::cast(
+        FWObjectReference::getObject(intf_re->front()));
     assert(rule_iface);
     
-    port=TCPUDPService::cast(srv)->getDstRangeStart();
+    port = TCPUDPService::cast(srv)->getDstRangeStart();
 
     for (FWObject::iterator i=rel->begin(); i!=rel->end(); ++i)
     {
-        FWObject *o = *i;
-        if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-//        Address *a;
+        FWObject *o = FWReference::getObject(*i);
 
         if (dynamic_cast<PIXObjectGroup*>(o)!=NULL)
         {
             for (FWObject::iterator j=o->begin(); j!=o->end(); ++j)
             {
-                FWObject *o1 = *j;
-                if (FWReference::cast(o1)!=NULL) 
-                    o1=FWReference::cast(o1)->getPointer();
-                Address *a=Address::cast(o1);
+                Address *a = Address::cast(FWReference::getObject(*j));
                 assert(a!=NULL);
-                str << _printSingleSSHTelnetCommand(
-                    port, a, rule_iface->getLabel());
+                str << _printSingleSSHTelnetCommand(port, a, rule_iface->getLabel());
             }
         } else
         {
-            Address *a=Address::cast(o);
+            Address *a = Address::cast(o);
             assert(a!=NULL);
-            str << _printSingleSSHTelnetCommand(
-                port, a, rule_iface->getLabel());
+            str << _printSingleSSHTelnetCommand(port, a, rule_iface->getLabel());
         }
     }
 
     return str.str();
 }
 
-string PolicyCompiler_pix::PrintRule::_printSingleSSHTelnetCommand(int port,
-                                                Address *a,
-                                                const string &interfaceLabel)
+string PolicyCompiler_pix::PrintRule::_printSingleSSHTelnetCommand(
+    int port, Address *a, const string &interfaceLabel)
 {
     string res;
 
-    if (port==23) 
+    if (port==22) res = "ssh ";
+    if (port==23) res = "telnet ";
+    if (port==80) res = "http ";
+
+    if (!res.empty())
     {
-        res += "telnet ";
-        res += a->getAddressPtr()->toString() + " " 
-            + a->getNetmaskPtr()->toString() + " "
-            + interfaceLabel     + "\n";
-    }
-    if (port==22) 
-    {
-        res += "ssh    ";
         res += a->getAddressPtr()->toString() + " " 
             + a->getNetmaskPtr()->toString() + " "
             + interfaceLabel     + "\n";
     }
+
     return res;
 }
 
@@ -440,13 +367,12 @@ string PolicyCompiler_pix::PrintRule::_printSingleSSHTelnetCommand(int port,
  */
 bool PolicyCompiler_pix::PrintRule::processNext()
 {
-    PolicyCompiler_pix *pix_comp=dynamic_cast<PolicyCompiler_pix*>(compiler);
-    PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    //bool write_comments= compiler->fw->getOptionsObject()->getBool("pix_include_comments");
+    PolicyCompiler_pix *pix_comp = dynamic_cast<PolicyCompiler_pix*>(compiler);
+    PolicyRule *rule = getNext(); if (rule==NULL) return false;
 
     tmp_queue.push_back(rule);
 
-    ostringstream  comment;
+    ostringstream comment;
     
     compiler->output << compiler->printComment(rule, current_rule_label1, "!");
 
@@ -459,7 +385,7 @@ bool PolicyCompiler_pix::PrintRule::processNext()
 //        return true;
     } 
 
-    if (rule->getBool("ssh_telnet_cmd"))
+    if (rule->getBool("tcp_service_to_fw"))
     {
         compiler->output << _printSSHTelnetCommand(rule);
         return true;
@@ -470,42 +396,26 @@ bool PolicyCompiler_pix::PrintRule::processNext()
      * be either group (in case processor CreateObjectGroups created
      * object group for it) or a regular object
      */
-    RuleElementSrc *src=rule->getSrc();
-    RuleElementDst *dst=rule->getDst();
-    RuleElementSrv *srv=rule->getSrv();
+    RuleElementSrc *src = rule->getSrc();
+    RuleElementDst *dst = rule->getDst();
+    RuleElementSrv *srv = rule->getSrv();
 
     assert(src->size()==1);
     assert(dst->size()==1);
     assert(srv->size()==1);
 
-    FWObject *srcobj=src->front();
-    FWObject *dstobj=dst->front();
-    FWObject *srvobj=srv->front();
+    FWObject *srcobj = FWReference::getObject(src->front());
+    FWObject *dstobj = FWReference::getObject(dst->front());
+    FWObject *srvobj = FWReference::getObject(srv->front());
 
     assert(srcobj);
     assert(dstobj);
     assert(srvobj);
 
-    if (FWReference::cast(srcobj)!=NULL)
-    {
-        srcobj=FWReference::cast(srcobj)->getPointer();
-        assert(srcobj);
-    }
-    if (FWReference::cast(dstobj)!=NULL)
-    {
-        dstobj=FWReference::cast(dstobj)->getPointer();
-        assert(dstobj);
-    }
-    if (FWReference::cast(srvobj)!=NULL)
-    {
-        srvobj=FWReference::cast(srvobj)->getPointer();
-        assert(srvobj);
-    }
-
     ostringstream  aclstr;
 
-    string acl_name=rule->getStr("acl");
-    assert (acl_name!="");
+    string acl_name = rule->getStr("acl");
+    assert(acl_name!="");
 
     ciscoACL *acl = pix_comp->acls[acl_name];
     assert(acl!=NULL);
@@ -522,52 +432,72 @@ bool PolicyCompiler_pix::PrintRule::processNext()
     aclstr << _printAction(rule);
 
     /*
-     * processor splitServices guaranties that rule has services of
-     * the same type (that is, the same protocol, like all tcp, all
-     * udp, all icmp or all IP with the same protocol number). PIX can
-     * use object-group for protocol only if protocol numbers are
-     * different and these are not icmp/tcp/udp protocols. This means
-     * that because of processor splitServices we never use
-     * object-group in protocol part of ACL.
+     * processor groupServicesByProtocol guaranties that rule has
+     * services of the same type (that is, the same protocol, like all
+     * tcp, all udp, all icmp or all IP with the same protocol
+     * number). PIX can use object-group for protocol only if protocol
+     * numbers are different and these are not icmp/tcp/udp
+     * protocols. This means that because of processor
+     * groupServicesByProtocol we never use object-group in protocol
+     * part of ACL.
      */
 
     PIXObjectGroup *pgsrv = PIXObjectGroup::cast(srvobj);
     PIXObjectGroup *pgsrc = PIXObjectGroup::cast(srcobj);
     PIXObjectGroup *pgdst = PIXObjectGroup::cast(dstobj);
+    Service *srv_s = Service::cast(srvobj);
+    assert(pgsrv!=NULL || srv_s!=NULL);
 
     if ( pgsrv!=NULL && pgsrv->isServiceGroup())
+    {
         aclstr << pgsrv->getSrvTypeName();
-    else
-        aclstr << Service::cast(srvobj)->getProtocolName();
+    } else
+        aclstr << srv_s->getProtocolName();
 
     aclstr << " ";
 
-    if ( pgsrc!=NULL && pgsrc->isObjectGroup())
+    NamedObject* asa8_object;
+
+    asa8_object = pix_comp->named_objects_manager->getNamedObject(srcobj);
+    if (asa8_object)
     {
-        aclstr << "object-group " << srcobj->getName();
-        aclstr << " ";
+        aclstr << "object " << asa8_object->getCommandWord().toStdString() << " ";
     } else
     {
-        aclstr << _printAddr( compiler->getFirstSrc(rule) );
+        if (pgsrc!=NULL)
+        {
+            aclstr << "object-group " << srcobj->getName() << " ";
+        } else
+        {
+            aclstr << _printAddr(Address::cast(srcobj));
+        }
     }
 
     if ( pgsrv==NULL ) 
         aclstr << _printSrcService( compiler->getFirstSrv(rule) );
 
-    if ( pgdst!=NULL && pgdst->isObjectGroup())
+    asa8_object = pix_comp->named_objects_manager->getNamedObject(dstobj);
+    if (asa8_object)
     {
-        aclstr << "object-group " << dstobj->getName();
-        aclstr << " ";
-    } else 
-        aclstr << _printAddr( compiler->getFirstDst(rule) );
-
-
-    if ( pgsrv!=NULL )
+        aclstr << "object "  << asa8_object->getCommandWord().toStdString() << " ";
+    } else
     {
-        aclstr << "object-group " << srvobj->getName();
-        aclstr << " ";
-    } else 
-        aclstr << _printDstService( compiler->getFirstSrv(rule) );
+        if (pgdst!=NULL)
+        {
+            aclstr << "object-group " << dstobj->getName() << " ";
+        } else
+        {
+            aclstr << _printAddr(Address::cast(dstobj));
+        }
+    }
+
+    if (pgsrv!=NULL)
+    {
+        aclstr << "object-group " << srvobj->getName() << " ";
+    } else
+    {
+        aclstr << _printDstService(Service::cast(srvobj));
+    }
 
     aclstr << _printLog( rule );
 
