@@ -15,6 +15,8 @@
  */
 
 #include "RoutingCompiler_cisco.h"
+#include "NamedObjectsAndGroupsSupport.h"
+#include "NamedObjectsManager.h"
 
 #include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/RuleElement.h"
@@ -24,21 +26,7 @@
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Network.h"
 
-#include <stack>
-
-#include <iostream>
-#if __GNUC__ > 3 || \
-    (__GNUC__ == 3 && (__GNUC_MINOR__ > 2 || (__GNUC_MINOR__ == 2 ) ) ) || \
-    _MSC_VER
-#  include <streambuf>
-#else
-#  include <streambuf.h>
-#endif
-#include <iomanip>
-#include <fstream>
-#include <sstream>
 #include <string>
-
 #include <assert.h>
 
 using namespace libfwbuilder;
@@ -109,3 +97,7 @@ string RoutingCompiler_cisco::debugPrintRule(Rule *r)
     return s;
 }
 
+void RoutingCompiler_cisco::setNamedObjectsManager(NamedObjectsManager *mgr)
+{
+    named_objects_manager = mgr;
+}
