@@ -15,6 +15,7 @@
  */
 
 #include "RoutingCompiler_cisco.h"
+#include "NamedObjectsAndGroupsSupport.h"
 
 #include "fwbuilder/RuleElement.h"
 #include "fwbuilder/Routing.h"
@@ -28,19 +29,6 @@
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/FWOptions.h"
 
-
-#include <iostream>
-#if __GNUC__ > 3 || \
-    (__GNUC__ == 3 && (__GNUC_MINOR__ > 2 || (__GNUC_MINOR__ == 2 ) ) ) || \
-    _MSC_VER
-#  include <streambuf>
-#else
-#  include <streambuf.h>
-#endif
-#include <iomanip>
-#include <fstream>
-#include <sstream>
-
 #include <assert.h>
 
 using namespace libfwbuilder;
