@@ -472,7 +472,10 @@ void interfaceProperties::guessSubInterfaceTypeAndAttributes(Interface *intf)
     if (parent_intf == NULL)
         return;
 
-    FWObject *f = Host::getParentHost(intf);
+    // Do not modify read-only object
+    if (intf->isReadOnly()) return;
+
+    //FWObject *f = Host::getParentHost(intf);
     //FWObject *f = intf->getParentHost();
 
     // Resources* os_res = Resources::os_res[f->getStr("host_OS")];
