@@ -34,6 +34,10 @@
 #include <ios>
 #include <iostream>
 #include <algorithm>
+#include <memory>
+
+#include "interfaceProperties.h"
+#include "interfacePropertiesObjectFactory.h"
 
 #include "fwbuilder/Address.h"
 #include "fwbuilder/AddressRange.h"
@@ -163,6 +167,8 @@ Importer::~Importer()
 
 void Importer::clear()
 {
+    last_comment.clear();
+
     action = "";
 
     protocol = "";
@@ -246,16 +252,17 @@ void Importer::setDiscoveredPlatform(const std::string &v)
     addMessageToLog("Platform: " + v);
 }
 
-void Importer::newInterface(const std::string &name)
+Interface* Importer::newInterface(const std::string &name)
 {
-    if (all_interfaces.count(name)>0) return;
+    if (all_interfaces.count(name)>0) return all_interfaces[name];
     ObjectMaker maker(Library::cast(library), error_tracker);
     FWObject *nobj = commitObject(
         maker.createObject(getFirewallObject(), Interface::TYPENAME, name));
     current_interface = Interface::cast(nobj);
     current_interface->setUnnumbered(true);
     all_interfaces[name] = current_interface;
-    addMessageToLog("New interface: " + name);
+    addMessageToLog(QObject::tr("New interface: %1").arg(name.c_str()));
+    return current_interface;
 }
 
 /*
@@ -556,10 +563,26 @@ void Importer::pushRule()
     // then add it to the current ruleset
     current_ruleset->ruleset->add(current_rule);
 
+    if (error_tracker->hasWarnings())
+    {
+        QStringList warn = error_tracker->getWarnings();
+        // parser errors and warnings are added to the log by
+        // PFCfgParser::reportError() and PFCfgParser::reportWarning()
+        // so we dont need to add them again here
+        foreach(QString w, warn)
+        {
+            if (!w.startsWith("Parser warning:")) addMessageToLog("Warning: " + w);
+        }
+        markCurrentRuleBad();
+    }
+
     if (error_tracker->hasErrors())
     {
         QStringList err = error_tracker->getErrors();
-        addMessageToLog("Error: " + err.join("\n"));
+        foreach(QString e, err)
+        {
+            if (!e.startsWith("Parser error:")) addMessageToLog("Error: " + e);
+        }
         markCurrentRuleBad();
     }
 
@@ -582,48 +605,38 @@ void Importer::setDstSelf()
     dst_a = "self";
 }    
 
-FWObject* Importer::makeSrcObj()
+FWObject* Importer::makeAddressObj(const std::string addr, const std::string netm)
 {
-    if (src_a == "self")
+    if (addr == "self")
     {
         return getFirewallObject();
     }
 
-    if ( (src_a=="" && src_nm=="") || 
-         (src_a==InetAddr::getAny().toString() &&
-          src_nm==InetAddr::getAny().toString()))
+    if ( (addr=="" && netm=="") || 
+         (addr==InetAddr::getAny().toString() &&
+          netm==InetAddr::getAny().toString()))
         return NULL;  // this is 'any'
 
-    if (src_nm=="") src_nm = InetAddr::getAllOnes().toString();
-
     ObjectSignature sig(error_tracker);
     sig.type_name = Address::TYPENAME;
-    sig.setAddress(src_a.c_str());
-    sig.setNetmask(src_nm.c_str(), address_maker->getInvertedNetmasks());
+    sig.setAddress(addr.c_str());
+    if (netm=="") 
+        sig.setNetmask(InetAddr::getAllOnes().toString().c_str(),
+                       address_maker->getInvertedNetmasks());
+    else
+        sig.setNetmask(netm.c_str(), address_maker->getInvertedNetmasks());
 
     return commitObject(address_maker->createObject(sig));
 }
 
+FWObject* Importer::makeSrcObj()
+{
+    return makeAddressObj(src_a, src_nm);
+}
+
 FWObject* Importer::makeDstObj()
 {
-    if (dst_a == "self")
-    {
-        return getFirewallObject();
-    }
-
-    if ( (dst_a=="" && dst_nm=="") || 
-         (dst_a==InetAddr::getAny().toString() &&
-          dst_nm==InetAddr::getAny().toString()))
-        return NULL;  // this is 'any'
-
-    if (dst_nm=="") dst_nm=InetAddr::getAllOnes().toString();
-
-    ObjectSignature sig(error_tracker);
-    sig.type_name = Address::TYPENAME;
-    sig.setAddress(dst_a.c_str());
-    sig.setNetmask(dst_nm.c_str(), address_maker->getInvertedNetmasks());
-
-    return commitObject(address_maker->createObject(sig));
+    return makeAddressObj(dst_a, dst_nm);
 }
 
 FWObject* Importer::makeSrvObj()
@@ -795,6 +808,9 @@ void Importer::markCurrentRuleBad()
     if ( ! current_rule->getComment().empty())
         comment.append(QString::fromUtf8(current_rule->getComment().c_str()));
 
+    foreach(QString err, error_tracker->getWarnings())
+        comment.append(err);
+
     foreach(QString err, error_tracker->getErrors())
         comment.append(err);
 
@@ -881,10 +897,10 @@ QString Importer::commonFailureErrorMessage()
         "file you are trying to import is in one of supported "
         "formats. Currently fwbuilder can only import "
         "iptables configuration saved with "
-        "'iptables-restore' command and Cisco routers (IOS) "
-        "configurations saved with 'show run' command. Import "
-        "of cisco ASA (PIX) configuration is not supported "
-        "at this time");
+        "'iptables-restore' command, Cisco routers (IOS), "
+        "Cisco ASA, FWSM and PIX configurations saved with "
+        "'show run' command and PF configuration from a pf.conf file."
+    );
 }
 
 void Importer::addMessageToLog(const std::string &msg)
@@ -894,10 +910,26 @@ void Importer::addMessageToLog(const std::string &msg)
 
 void Importer::addMessageToLog(const QString &msg)
 {
-    QString log_line("%1: %2\n");
-    *logger << log_line.arg(getCurrentLineNumber()).arg(msg).toUtf8().constData();
+    if (getCurrentLineNumber() >= 0)
+    {
+        QString log_line("%1: %2\n");
+        *logger << log_line.arg(getCurrentLineNumber()).arg(msg).toUtf8().constData();
+    } else
+    {
+        *logger << msg.toUtf8().constData();
+    }
 }
 
+/**
+ * This function adds "standard" comment to the object, plus text
+ * passed as @additional_comment argument. If the object already has
+ * some comment, it is preserved and new text is appended to it. If
+ * flag add_standard_comments is false, then comment referring to the
+ * line number in the original file is not added, but
+ * @additional_comment is added anyway. Note that we also add comments
+ * to rules in case of errors but those are not suppressed by the flag
+ * add_standard_comments
+ */
 void Importer::addStandardImportComment(FWObject *obj,
                                         const QString &additional_comment)
 {
@@ -916,10 +948,13 @@ void Importer::addStandardImportComment(FWObject *obj,
 
     if ( ! additional_comment.isEmpty()) comment << additional_comment;
 
-    QString file_and_line("Created during import of %1 line %2");
-    comment << file_and_line
-        .arg(QString::fromUtf8(input_file_name.c_str()))
-        .arg(getCurrentLineNumber());
+    if (add_standard_comments)
+    {
+        QString file_and_line("Created during import of %1 line %2");
+        comment << file_and_line
+            .arg(QString::fromUtf8(input_file_name.c_str()))
+            .arg(getCurrentLineNumber());
+    }
 
     obj->setComment(comment.join("\n").toUtf8().constData());
     obj->setBool(".import-commited", true);
@@ -933,3 +968,76 @@ FWObject* Importer::commitObject(FWObject *obj)
     return obj;
 }
 
+/*
+ * Rearrange vlan interfaces. Importer creates all interfaces as
+ * children of the firewall. Vlan interfaces should become
+ * subinterfaces of the corresponding physical interfaces.
+ */
+void Importer::rearrangeVlanInterfaces()
+{
+    std::auto_ptr<interfaceProperties> int_prop(
+        interfacePropertiesObjectFactory::getInterfacePropertiesObject(
+            getFirewallObject()));
+
+    list<FWObject*> all_interface_objects =
+        getFirewallObject()->getByTypeDeep(Interface::TYPENAME);
+    list<FWObject*> vlans;
+    list<FWObject*>::iterator it;
+    for (it=all_interface_objects.begin(); it!=all_interface_objects.end(); ++it)
+    {
+        Interface *intf = Interface::cast(*it);
+        FWOptions *ifopt = intf->getOptionsObject();
+        
+        if (int_prop->looksLikeVlanInterface(intf->getName().c_str()) &&
+            ifopt->getStr("type")=="8021q")
+        {
+            qDebug() << "Found vlan interface" << intf->getName().c_str();
+            vlans.push_back(intf);
+        }
+    }
+
+    for (it=vlans.begin(); it!=vlans.end(); ++it)
+    {
+        Interface *vlan_intf = Interface::cast(*it);
+
+        qDebug() << "VLAN " << vlan_intf->getName().c_str();
+
+        QString base_name;
+        int vlan_id;
+        int_prop->parseVlan(vlan_intf->getName().c_str(), &base_name, &vlan_id);
+
+        qDebug() << "base name" << base_name;
+
+        if ( ! base_name.isEmpty())
+        {
+            getFirewallObject()->remove(vlan_intf, false); // do not delete
+
+            list<FWObject*>::iterator it2;
+            for (it2=all_interface_objects.begin(); it2!=all_interface_objects.end(); ++it2)
+            {
+                if (base_name == (*it2)->getName().c_str())
+                {
+                    (*it2)->add(vlan_intf, false);
+                    break;
+                }
+            }
+        }
+    }
+
+}
+
+void Importer::registerBrokenObject(FWObject *obj, const QString &err)
+{
+    broken_objects[obj] = err;
+}
+
+bool Importer::isObjectBroken(FWObject *obj)
+{
+    return broken_objects.count(obj) != 0;
+}
+
+QString Importer::getBrokenObjectError(FWObject *obj)
+{
+    return broken_objects[obj];
+}
+
