@@ -224,10 +224,12 @@ void AutomaticRules_ipt::addFailoverRules()
         os_res->getResourceStr(
             "/FWBuilderResources/Target/protocols/openais/default_address");
 
-    FWObjectTypedChildIterator interfaces = fw->findByType(Interface::TYPENAME);
-    for (; interfaces != interfaces.end(); ++interfaces)
+    list<FWObject*> interfaces = fw->getByTypeDeep(Interface::TYPENAME);
+    interfaces.sort(FWObjectNameCmpPredicate());
+    list<FWObject*>::iterator iface_i;
+    for (iface_i=interfaces.begin(); iface_i != interfaces.end(); ++iface_i)
     {
-        Interface *iface = Interface::cast(*interfaces);
+        Interface *iface = Interface::cast(*iface_i);
 
         /*
           We add copies of cluster interface objects to fw objects
