@@ -307,40 +307,6 @@ namespace fwcompiler
 	 */
         DECLARE_NAT_RULE_PROCESSOR(splitMultipleICMP);
 
-        /**
-         * prepare for negation of single objects in rule elements
-         */
-        class singleObjectNegation : public NATRuleProcessor
-        {
-            std::string re_type;
-            public:
-            singleObjectNegation(const std::string &n,std::string _type):
-                NATRuleProcessor(n) { re_type=_type; }
-            virtual bool processNext();
-        };
-
-	/**
-         * single object negation in OSrc
-	 */
-        class singleObjectNegationOSrc : public singleObjectNegation
-        {
-            public:
-            singleObjectNegationOSrc(const std::string &n):
-                singleObjectNegation(n,libfwbuilder::RuleElementOSrc::TYPENAME)
-                {}
-        };
-
-	/**
-         * single object negation in ODst
-	 */
-        class singleObjectNegationODst : public singleObjectNegation
-        {
-            public:
-            singleObjectNegationODst(const std::string &n):
-                singleObjectNegation(n,libfwbuilder::RuleElementODst::TYPENAME)
-                {}
-        };
-
         /**
          *  deals with negation in OSrc 
          */
