@@ -654,7 +654,7 @@ int OSConfigurator_secuwall::generateInterfaceFile (Interface * iface, string na
     stream << "\"" << endl;
 
     /* Address object contains host, network and broadcast address plus netmask */
-    const Address* ipAddr;
+    const Address* ipAddr = NULL;
     if (ip_address != NULL)
         ipAddr = ip_address->getAddressObject();
 
@@ -948,6 +948,8 @@ int OSConfigurator_secuwall::generateSSHKeys()
         cout << " Found existing DSA key: skipping key generation." << endl;
     }
 
+    Q_UNUSED(i);
+
     /* Add RSA pub key of fwadmin to the firewall's known hosts file */
     fwadmin_keyfilename = getenv("HOME");
     fwadmin_keyfilename += fwadmin_ssh_key;
