@@ -82,6 +82,9 @@ protected:
         typedef std::list<std::string> chain_list;
         std::map<std::string, chain_list*> chains;
 
+        // number of bridge interfaces (br0 / br1 / etc)
+        int bridge_count;
+        
         // use minus_n_commands map to track creation of chains.
         // Using external map object for this to be able to track
         // new chains across different compiler runs (used to process
@@ -488,6 +491,46 @@ protected:
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(splitIfDstAny);
 
+        /**
+         * Split rule if src has addressRange object that matches the
+         * firewall
+         */
+        DECLARE_POLICY_RULE_PROCESSOR(splitIfSrcMatchingAddressRange);
+
+        /**
+         * Split rule if dst has addressRange object that matches the
+         * firewall
+         */
+        DECLARE_POLICY_RULE_PROCESSOR(splitIfDstMatchingAddressRange);
+
+        /**
+         * If rule element RE has an AddressRange object that
+         * represents single address, replace it with corresponding
+         * IPv4 object
+         */
+        class specialCaseAddressRangeInRE : public PolicyRuleProcessor
+        {
+            std::string re_type;
+            public:
+            specialCaseAddressRangeInRE(const std::string &name,
+                      const std::string &t) : PolicyRuleProcessor(name) { re_type=t; }
+            virtual bool processNext();
+        };
+
+        class specialCaseAddressRangeInSrc : public specialCaseAddressRangeInRE
+        {
+        public:
+        specialCaseAddressRangeInSrc(const std::string &n) :
+            specialCaseAddressRangeInRE(n,libfwbuilder::RuleElementSrc::TYPENAME) {}
+        };
+
+        class specialCaseAddressRangeInDst : public specialCaseAddressRangeInRE
+        {
+        public:
+        specialCaseAddressRangeInDst(const std::string &n) :
+            specialCaseAddressRangeInRE(n,libfwbuilder::RuleElementDst::TYPENAME) {}
+        };
+        
 	/**
 	 * split rule if Src==any 
 	 * 
@@ -966,6 +1009,7 @@ public:
             have_connmark_in_output = false;
             my_table = "filter";
             minus_n_commands = m_n_commands_map;
+            bridge_count = 0;
         }
         virtual ~PolicyCompiler_ipt();
 
