@@ -190,11 +190,15 @@ bool RoutingCompiler_ipt::PrintRule::processNext()
             }
             compiler->output << "# " << comm.substr(c1) << endl;
             compiler->output << "# " << endl;
+
+            string err = compiler->getErrorsForRule(rule, "# ");
+            if (!err.empty()) compiler->output << err << endl;
+
             current_rule_label = rl;
         }
         
-        string err = rule->getStr(".error_msg");
-        if (!err.empty()) compiler->output << "# " << err << endl;
+//        string err = rule->getCompilerMessage();
+//        if (!err.empty()) compiler->output << "# " << err << endl;
 
         string  command_line = RoutingRuleToString(rule);
         compiler->output << command_line;
