@@ -39,7 +39,7 @@
 # define nil NULL
 #endif
 
-#include "../../../config.h"
+#include "config.h"
 
 #include <string>
 #include <map>
@@ -53,7 +53,7 @@
 #  include <io.h>
 #endif
 
-#include <fwbuilder/FWException.h>
+#include "fwbuilder/FWException.h"
 
 namespace libfwbuilder
 {
