@@ -27,7 +27,7 @@
 #ifndef __BLANKDIALOG_H_
 #define __BLANKDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_blankdialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
