@@ -17,7 +17,7 @@
 #ifndef __CLUSTERDIALOG_H_
 #define __CLUSTERDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_clusterdialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
