@@ -53,11 +53,6 @@ ClusterGroupDialog::~ClusterGroupDialog()
     delete m_dialog;
 }
 
-void ClusterGroupDialog::getHelpName(QString *str)
-{
-    *str = "ClusterGroupDialog";
-}
-
 ClusterGroupDialog::ClusterGroupDialog(QWidget *parent)
     : BaseObjectDialog(parent)
 {
@@ -65,6 +60,8 @@ ClusterGroupDialog::ClusterGroupDialog(QWidget *parent)
     m_dialog->setupUi(this);
     obj = NULL;
     reload = false;
+
+    connectSignalsOfAllWidgetsToSlotChange();
 }
 
 void ClusterGroupDialog::loadFWObject(FWObject *o)
@@ -118,11 +115,9 @@ void ClusterGroupDialog::loadFWObject(FWObject *o)
             "type", possible_cluster_group_types.front().first.toStdString());
 
     m_dialog->obj_name->setText(QString::fromUtf8(g->getName().c_str()));
-    m_dialog->comment->setText(QString::fromUtf8(g->getComment().c_str()));
+    m_dialog->commentKeywords->loadFWObject(o);
     m_dialog->obj_name->setEnabled(!o->isReadOnly());
     setDisabledPalette(m_dialog->obj_name);
-    m_dialog->comment->setReadOnly(o->isReadOnly());
-    setDisabledPalette(m_dialog->comment);
 
     QString grp_type = obj->getStr("type").c_str();
     m_dialog->type->clear();
@@ -205,7 +200,8 @@ void ClusterGroupDialog::addIcon(FWObject *o, bool master)
 {
     FWObject *iface = o;
     assert(Interface::cast(iface)!=NULL);
-    FWObject *fw = Interface::cast(iface)->getParentHost(); // because iface can be subinterface
+    FWObject *fw = Host::getParentHost(iface);
+//    FWObject *fw = Interface::cast(iface)->getParentHost(); // because iface can be subinterface
     bool valid = cluster->validateMember(Firewall::cast(fw));
     QString iface_name = QString::fromUtf8(iface->getName().c_str());
     QString fw_name = QString::fromUtf8(fw->getName().c_str());
@@ -288,7 +284,7 @@ void ClusterGroupDialog::applyChanges()
 
     QString oldname = obj->getName().c_str();
     new_state->setName(string(m_dialog->obj_name->text().toUtf8().constData()));
-    new_state->setComment(string(m_dialog->comment->toPlainText().toUtf8().constData()));
+    m_dialog->commentKeywords->applyChanges(new_state);
 
     saveGroupType(new_state);
 
