@@ -31,6 +31,7 @@
 #include <fwbuilder/FWObject.h>
 //Added by qt3to4:
 #include <QDropEvent>
+#include <QWidget>
 
 using namespace std;
 using namespace libfwbuilder;
@@ -95,7 +96,12 @@ QByteArray FWObjectDrag::encodedData() const
 
 bool FWObjectDrag::decode( QDropEvent *ev, list<FWObject*> &ol)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
     QByteArray rawdata = ev->encodedData( static_cast<const char*>(FWB_MIME_TYPE.toLatin1()) );
+#else
+    QByteArray rawdata = ev->mimeData()->data(FWB_MIME_TYPE);
+#endif
+
 
     ol.clear();
     QDataStream stream(&rawdata, QIODevice::ReadOnly);
@@ -116,7 +122,11 @@ bool FWObjectDrag::decode( QDropEvent *ev, list<FWObject*> &ol)
 
 bool FWObjectDrag::decode( QDragEnterEvent *ev, list<FWObject*> &ol)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
     QByteArray rawdata = ev->encodedData( static_cast<const char*>(FWB_MIME_TYPE.toLatin1()) );
+#else
+    QByteArray rawdata = ev->mimeData()->data(FWB_MIME_TYPE);
+#endif
 
     ol.clear();
     QDataStream stream(&rawdata, QIODevice::ReadOnly);
