@@ -62,7 +62,11 @@ protected:
         
 public:
     Ui::FWObjectDropArea_q *m_objectDropArea;
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
     FWObjectDropArea(QWidget*p, const char * n = 0, Qt::WFlags f = 0);
+#else
+    FWObjectDropArea(QWidget*p, const char * n = 0, Qt::WindowFlags f = 0);
+#endif
     ~FWObjectDropArea(); 
     libfwbuilder::FWObject * getObject(){return object;};
     void setObject(libfwbuilder::FWObject * o){ object = o ;};
