@@ -27,7 +27,7 @@
 #ifndef __FINDWHEREUSEDWIDGET_H_
 #define __FINDWHEREUSEDWIDGET_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_findwhereusedwidget_q.h>
 #include "ProjectPanel.h"
 
