@@ -77,8 +77,11 @@ bool FirewallInstaller::parseManifestLine(const QString &line,
     if (line.indexOf(MANIFEST_MARKER) == -1) return false;
 
     if (fwbdebug)
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         qDebug("Manifest line: '%s'", line.toAscii().constData());
-
+#else
+        qDebug("Manifest line: '%s'", line.toLatin1().constData());
+#endif
     QString workline = line.split(MANIFEST_MARKER)[1].trimmed();
     if (workline.startsWith("*"))
     {
@@ -120,9 +123,17 @@ bool FirewallInstaller::parseManifestLine(const QString &line,
 
     if (fwbdebug)
         qDebug() << "local_name:"
+            #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
                  << local_file_name->toAscii().constData()
+            #else
+                 << local_file_name->toLatin1().constData()
+            #endif
                  << "remote_name:"
+            #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
                  << remote_file_name->toAscii().constData()
+            #else
+                 << remote_file_name->toLatin1().constData()
+            #endif
                  << "main_script:" 
                  << *main_script;
 
@@ -412,10 +423,18 @@ void FirewallInstaller::packSCPArgs(const QString &local_name,
 
     try
     {
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         InetAddr addr(AF_INET6, cnf->maddr.toAscii().constData());
+#else
+        InetAddr addr(AF_INET6, cnf->maddr.toLatin1().constData());
+#endif
         if (fwbdebug)
             qDebug("SCP will talk to the firewall using address %s ( %s )",
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
                    cnf->maddr.toAscii().constData(),
+#else
+                   cnf->maddr.toLatin1().constData(),
+#endif
                    addr.toString().c_str());
         /*
          * It looks like if cnf->maddr is a host name, then InetAddr
@@ -571,9 +590,17 @@ void FirewallInstaller::copyFile(const QString &local_name, const QString &remot
     packSCPArgs(local_name, remote_name, args);
 
     inst_dlg->addToLog( tr("Copying %1 -> %2:%3\n")
+                    #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
                         .arg(QString::fromUtf8(local_name.toAscii().constData()))
+                    #else
+                        .arg(QString::fromUtf8(local_name.toLatin1().constData()))
+                    #endif
                         .arg(cnf->maddr)
+                    #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
                         .arg(QString::fromUtf8(remote_name.toAscii().constData())));
+                    #else
+                        .arg(QString::fromUtf8(remote_name.toLatin1().constData())));
+                    #endif
 
     if (cnf->verbose) inst_dlg->displayCommand(args);
     qApp->processEvents();
