@@ -28,7 +28,7 @@
 #define __FIREWALLINSTALLERPROCURVE_H_
 
 
-#include "../../config.h"
+#include "config.h"
 
 #include "FirewallInstallerCisco.h"
 
