@@ -27,7 +27,7 @@
 #ifndef __GROUPOBJECTDIALOG_H_
 #define __GROUPOBJECTDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_groupobjectdialog_q.h>
 
 #include <qtooltip.h>
