@@ -27,7 +27,7 @@
 #ifndef __HOSTDIALOG_H_
 #define __HOSTDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_hostdialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
