@@ -26,7 +26,7 @@
 #ifndef ICONSETTER_H
 #define ICONSETTER_H
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 #include "fwbuilder/FWObject.h"
 #include <QPixmap>
