@@ -32,9 +32,16 @@
 #include "utils_no_qt.h"
 #include "platforms.h"
 
-#include <QtGui/QTabWidget>
-#include <QtGui/QToolButton>
-#include <QtGui/QHBoxLayout>
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#   include <QtGui/QTabWidget>
+#   include <QtGui/QToolButton>
+#   include <QtGui/QHBoxLayout>
+#else
+#   include <QtWidgets/QTabWidget>
+#   include <QtWidgets/QToolButton>
+#   include <QtWidgets/QHBoxLayout>
+#endif
+
 #include "fwbuilder/Interface.h"
 #include "fwbuilder/InterfaceData.h"
 #include "fwbuilder/FWObjectDatabase.h"
