@@ -27,7 +27,7 @@
 #ifndef __LIBRARYDIALOG_H_
 #define __LIBRARYDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_librarydialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
