@@ -124,6 +124,8 @@ class ObjectManipulator : public QWidget
 
     QMenu *popup_menu;
 
+    ObjectTreeViewItem *lastClickedItem;
+
 /* this is a reverse idex of all objects in all trees. We use it to
  * quickly locate given object in the tree and open it
  */
@@ -322,6 +324,8 @@ public:
                      const std::string &namesuffix);
      void autorenameVlans(std::list<libfwbuilder::FWObject*> &obj_list);
 
+     std::string getFolderNameString(libfwbuilder::FWObject *obj);
+
      void reload();
 
      void loadObjects();
@@ -488,8 +492,11 @@ public:
     
      void reminderAboutStandardLib();
      
+     void addSubfolderActions(QList<QAction*> &AddObjectActions, libfwbuilder::FWObject *currentObj, ObjectTreeViewItem *item, bool &addSubfolder);
 signals:
      void libraryAccessChanged(bool writable);
+
+
 };
 
 #endif
