@@ -246,6 +246,12 @@ void ObjectManipulator::createNewObject()
                     m_project->getFileName(), ruleset->getId()));
     }
 
+    //directly move object to it's subfolder
+    list<FWObject*> newObjs;
+    newObjs.push_back(new_obj);
+    moveItems(lastClickedItem, newObjs);
+    lastClickedItem = NULL;
+
     m_project->undoStack->push(macro);
 }
 
@@ -552,7 +558,7 @@ FWObject* ObjectManipulator::newCluster(QUndoCommand* macro, bool fromSelected)
             fwvector.push_back(FWObject::cast(fw));
         ncd->setFirewallList(fwvector);
     }
-    if ( ! ncd->exec() == QDialog::Accepted) return NULL;
+    if ( ncd->exec() != QDialog::Accepted) return NULL;
 
     FWObject *ncl = ncd->getNewCluster();
     delete ncd;
@@ -711,7 +717,6 @@ FWObject* ObjectManipulator::newHost(QUndoCommand* macro)
         parent->remove(o, false);
         new_state->add(o);
     }
-
     return o;
 }
 
