@@ -25,7 +25,7 @@
 
 
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 
 #include "ObjectManipulator.h"
@@ -34,7 +34,6 @@
 using namespace std;
 using namespace libfwbuilder;
 
-#ifndef ELC
 bool ObjectManipulator::isObjectAllowed(const QString&)
 {
     return true;
@@ -46,4 +45,3 @@ bool ObjectManipulator::isObjectAllowed(FWObject*, FWObject*)
     return true;
 }
 
-#endif
