@@ -110,7 +110,11 @@ protected:
     ObjectTreeView(ProjectPanel* project,
                    QWidget* parent = 0,
                    const char * name = 0,
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
                    Qt::WFlags f = 0);
+#else
+                   Qt::WindowFlags f = 0);
+#endif
 
     void freezeSelection(bool f) { selectionFrozen = f; }
 
