@@ -606,8 +606,34 @@ void RuleSetModel::insertRule(Rule *rule) {
     } else
     {
         QModelIndex index = this->index(targetRule);
-        ruleset->insert_before(targetRule,rule);
-        insertRuleToModel(rule, index, false);
+        /*
+         * Bugfix: when inserting a new rule abow a group, doing undo and then redo
+         * we need to check which group the rule really belongs to
+         */
+
+        if (targetRule->getStr("group") != rule->getStr("group")) {
+            // The new rule at the index we are about to re-insert
+            // are not in the same group as the old rule was
+
+            // We'll get the group name from the rule above the current index
+            targetRule = ruleset->getRuleByNum(rule->getPosition() - 1);
+            if (targetRule) {
+                index = this->index(targetRule);
+                ruleset->insert_after(targetRule,rule);
+                insertRuleToModel(rule, index, true);
+            } else {
+                // We are inserting on the top and there's no rule above
+                // the current index. Let's just insert the rule at the top then,
+                // and not put it into the group below
+                rule->setParent(ruleset);
+                ruleset->insert_before(ruleset->getRuleByNum(0), rule);
+                index = QModelIndex();
+                insertRuleToModel(rule, index);
+            }
+        } else {
+            ruleset->insert_before(targetRule,rule);
+            insertRuleToModel(rule, index, false);
+        }
     }
     ruleset->renumberRules();
 }
@@ -1245,6 +1271,7 @@ int RuleSetModel::getRulePosition(QModelIndex index)
 
 void RuleSetModel::objectChanged(FWObject* object)
 {
+    Q_UNUSED(object)
 /*
  * See #2373
  *
@@ -1447,6 +1474,9 @@ QStringList PolicyModel::getRuleOptions(Rule* r) const
 
     if (policyRule->getLogging()) res << "Log";
 
+    if (!policyRule->getOptionsObject()->getStr("counter_name").empty())
+        res << "Accounting";
+
     if ( ! isDefaultPolicyRuleOptions(r->getOptionsObject())) res << "Options";
 
     FWObject *firewall = r;
@@ -1532,6 +1562,18 @@ void PolicyModel::initRule(Rule *new_rule, Rule *old_rule)
             newrule_as_policy_rule->setDirection(PolicyRule::Outbound); break;
         }
 
+        if (st->getInt("Objects/PolicyRule/defaultSource"))
+            newrule_as_policy_rule->setDummySource();
+
+        if (st->getInt("Objects/PolicyRule/defaultDestination"))
+            newrule_as_policy_rule->setDummyDestination();
+
+        if (st->getInt("Objects/PolicyRule/defaultService"))
+            newrule_as_policy_rule->setDummyService();
+
+        if (st->getInt("Objects/PolicyRule/defaultInterface"))
+            newrule_as_policy_rule->setDummyInterface();
+
         ruleopt->setBool("stateless",
                          ! st->getBool("Objects/PolicyRule/defaultStateful") ||
                          getStatelessFlagForAction(newrule_as_policy_rule));
