@@ -6,6 +6,11 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
+
+                 Copyright (C) 2013 UNINETT AS
+
+  Author:  Sirius Bakke <sirius.bakke@uninett.no>
+
   $Id$
 
   This program is free software which we release under the GNU General Public
@@ -26,7 +31,12 @@
 #ifndef RULESETVIEW_H
 #define RULESETVIEW_H
 
-#include <QtGui/QTreeView>
+#include <qglobal.h>
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#   include <QtGui/QTreeView>
+#else
+#   include <QtWidgets/QTreeView>
+#endif
 #include <QUndoCommand>
 
 #include "fwbuilder/Rule.h"
@@ -193,6 +203,8 @@ public slots:
     void cutSelectedObject();
     void pasteObject();
 
+    void convertToAny();
+
     void saveCollapsedGroups();
 
     void updateAllColumnsSize();
@@ -311,6 +323,9 @@ private:
     libfwbuilder::FWObject* createInsertTemplate(ProjectPanel* proj_p, int id);
     void setActionState(QAction *action, bool state);
 
+    bool useDummy(libfwbuilder::RuleElement* re) const;
+    void setDummy(libfwbuilder::RuleElement* re);
+    bool isDummy(libfwbuilder::RuleElement* re, int child) const;
 };
 
 class PolicyView : public RuleSetView
