@@ -43,7 +43,11 @@
 #include <string>
 
 #include <QtDebug>
-#include <QtGui>
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#   include <QtGui>
+#else
+#   include <QtWidgets>
+#endif
 #include<QStringList>
 
 
@@ -212,8 +216,7 @@ void RuleSetViewDelegate::paintRule(QPainter *painter,
 
     if (node != 0)
     {
-        FWOptions *ropt = node->rule->getOptionsObject();
-        QString color = ropt->getStr("color").c_str();
+        QString color = getRuleColor(node);
         if (!color.isEmpty())
         {
             painter->fillRect(option.rect, QColor(color));
@@ -312,6 +315,8 @@ void RuleSetViewDelegate::paintOptions(
         if (icon.contains("Log")) parameter = tr("log");
         if (icon.contains("Options")) parameter = tr("(options)");
 
+        if (icon.contains("Accounting")) parameter = tr("(counter)");
+
         drawIconAndText(painter,
                         itemRect.adjusted(
                             HORIZONTAL_MARGIN, VERTICAL_MARGIN,
@@ -375,14 +380,16 @@ void RuleSetViewDelegate::paintObject(
         }
 
         QString icon;
-        if (!re->isAny()) icon = QString(o1->getTypeName().c_str()); // + "/icon";
+        if (!re->isAny() && !re->isDummy()) icon = QString(o1->getTypeName().c_str()); // + "/icon";
         QString text = objectText(re, o1);
 
+        if (re->isDummy()) painter->setPen( QColor("darkred") );
+
         drawIconAndText(painter,
                         itemRect.adjusted(HORIZONTAL_MARGIN, VERTICAL_MARGIN, -HORIZONTAL_MARGIN, -VERTICAL_MARGIN),
                         icon, text, re->getNeg());
 
-        if ((sectionModel->selectedObject == o1) && !(option.state & QStyle::State_HasFocus) && !re->isAny())
+        if ((sectionModel->selectedObject == o1) && !(option.state & QStyle::State_HasFocus) && !re->isAny() && !re->isDummy())
         {
             painter->setPen( QColor("red") );
             painter->drawRect(itemRect.left()+1, itemRect.top()+1, itemRect.width()-2, itemRect.height()-2);
@@ -473,7 +480,7 @@ QSize RuleSetViewDelegate::sizeHint(const QStyleOptionViewItem & option,
         // make sure cell height is equal to max height of all cells
         // in the same row. See #2665
         QSize tallest_cell = QSize(0, 0);
-        for (unsigned int c=0; c<=index.column(); ++c)
+        for (int c=0; c<=index.column(); ++c)
         {
             QSize cell_size = node->sizes[c];
             if (cell_size.isValid())
@@ -526,6 +533,7 @@ QSize RuleSetViewDelegate::calculateCellSizeForRule(
     Q_UNUSED(node);
 
     QSize iconSize = getIconSize();
+    Q_UNUSED(iconSize);
     int itemHeight = getItemHeight();
 
     QSize result = QSize(50,itemHeight);
@@ -604,7 +612,7 @@ QSize RuleSetViewDelegate::calculateCellSizeForObject(const QModelIndex & index)
         }
     }
     QSize res = QSize(w+HORIZONTAL_MARGIN*2,h);
-    QModelIndex idx = index;
+    // QModelIndex idx = index; // Unused
     return res;
 }
 
@@ -712,3 +720,9 @@ DrawingContext RuleSetViewDelegate::initContext(
 
     return ctx;
 }
+
+QString RuleSetViewDelegate::getRuleColor(RuleNode *node) const
+{
+    FWOptions *ropt = node->rule->getOptionsObject();
+    return QString(ropt->getStr("color").c_str());
+}
