@@ -27,7 +27,7 @@
 #ifndef  __SSHIOS_H_
 #define  __SSHIOS_H_
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 
 #include "SSHCisco.h"
