@@ -146,7 +146,9 @@ void SSHSession::startSession()
     connect(proc,SIGNAL(finished( int, QProcess::ExitStatus )),
             this,  SLOT(finished( int ) ) );
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
     QTextCodec::setCodecForCStrings(QTextCodec::codecForName("latin1"));
+#endif
 
     assert(args.size() > 0);
 
@@ -194,11 +196,19 @@ void SSHSession::startSession()
 
     if (fwbdebug)
     {
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         qDebug("Launch external ssh client %s", program.toAscii().constData());
+#else
+        qDebug("Launch external ssh client %s", program.toLatin1().constData());
+#endif
         qDebug("Arguments:");
         QStringList::const_iterator i;
         for (i=arguments.begin(); i!=arguments.end(); ++i)
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
             qDebug("    %s", (*i).toAscii().constData());
+#else
+            qDebug("    %s", (*i).toLatin1().constData());
+#endif
     }
 
     proc->start(program, arguments);
@@ -291,7 +301,8 @@ void SSHSession::terminate()
             // this processes events and lets QProcess send signal finished()
             // in case user hit Cancel at just right time when background process
             // already exited but QProcess has not noticed this yet.
-            proc->waitForFinished(100);
+            if (proc != NULL)
+                proc->waitForFinished(100);
         }
 
         // If QProcess sent signal finished() while we were waiting in
@@ -561,7 +572,11 @@ void SSHSession::readFromStdout()
 
         stdoutBuffer.append(buf);
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         if (fwbdebug) qDebug() << buf.toAscii().constData() << "\n";
+#else
+        if (fwbdebug) qDebug() << buf.toLatin1().constData() << "\n";
+#endif
 
         bool endsWithLF = buf.endsWith("\n");
         QString lastLine = "";
@@ -632,8 +647,13 @@ void SSHSession::readFromStderr()
         if (ba.size()!=0)
         {
             QString s=QString(ba);
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
             if (fwbdebug) qDebug("SSHSession::readFromStderr  buf=%s",
                                  s.toAscii().constData());
+#else
+            if (fwbdebug) qDebug("SSHSession::readFromStderr  buf=%s",
+                                 s.toLatin1().constData());
+#endif
             emit printStdout_sign(s);
             stdoutBuffer.append(s);
             stateMachine();
@@ -713,8 +733,14 @@ bool SSHSession::cmpPrompt(const QString &str, const QString &prompt)
 {
 #if STATE_MACHINE_DEBUG
     if (fwbdebug)
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         qDebug("SSHSession::cmpPrompt: str='%s' prompt='%s'",
                str.toAscii().constData(),prompt.toAscii().constData());
+#else
+        qDebug("SSHSession::cmpPrompt: str='%s' prompt='%s'",
+               str.toLatin1().constData(),prompt.toLatin1().constData());
+#endif // QT_VERSION
+
 #endif
 
     bool res = false;
@@ -737,8 +763,14 @@ bool SSHSession::cmpPrompt(const QString &str,const QRegExp &prompt)
 {
 #if STATE_MACHINE_DEBUG
     if (fwbdebug)
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         qDebug("SSHSession::cmpPrompt: str='%s' prompt='%s' (regexp)",
                str.toAscii().constData(),prompt.pattern().toAscii().constData());
+#else
+        qDebug("SSHSession::cmpPrompt: str='%s' prompt='%s' (regexp)",
+               str.toLatin1().constData(),prompt.pattern().toLatin1().constData());
+#endif // QT_VERSION
+
 #endif
     if (str.isEmpty()) return false;
 
@@ -756,7 +788,11 @@ void SSHSession::sendCommand(const QString &cmd)
     stdoutBuffer = "";
     if (!dry_run)
     {
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         proc->write((cmd + "\n").toAscii());
+#else
+        proc->write((cmd + "\n").toLatin1());
+#endif
     } else
     {
         emit printStdout_sign(QString("[DRY RUN] %1\n").arg(cmd));
