@@ -25,7 +25,7 @@
 
 
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 
 #include "SimpleTextEditor.h"
