@@ -26,7 +26,7 @@
 #ifndef __SIMPLETEXTEDITOR_H__
 #define __SIMPLETEXTEDITOR_H__
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_simpletexteditor_q.h>
 
 class SimpleTextEditor : public QDialog
