@@ -32,6 +32,7 @@
 #include "FWBSettings.h"
 #include "FWWindow.h"
 #include "FirewallInstallerCisco.h"
+#include "FirewallInstallerJuniper.h"
 #include "FirewallInstallerProcurve.h"
 #include "FirewallInstallerUnx.h"
 #include "events.h"
@@ -118,13 +119,12 @@ bool instDialog::runInstaller(Firewall *fw, bool installing_many_firewalls)
 
         if (isCiscoFamily())
             installer = new FirewallInstallerCisco(this, &cnf, fwb_prompt);
-        else
-        {
-            if (isProcurve())
+        else if (isProcurve())
                 installer = new FirewallInstallerProcurve(this, &cnf, fwb_prompt);
-            else
+		else if (isJuniper())
+                installer = new FirewallInstallerJuniper(this, &cnf, fwb_prompt);
+        else
                 installer = new FirewallInstallerUnx(this, &cnf, fwb_prompt);
-        }
 
         if (!installer->packInstallJobsList(fw))
         {
