@@ -179,8 +179,13 @@ void newClusterDialog::createNewCluster()
         oi->add(failover_grp);
 
         QString failover_protocol_name = data.protocol.toLower();
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         failover_grp->setStr("type",
                              failover_protocol_name.toAscii().constData());
+#else
+        failover_grp->setStr("type",
+                             failover_protocol_name.toLatin1().constData());
+#endif
 
         typedef QPair<Firewall*, Interface*> intfpair;
         foreach(intfpair intf, member_interfaces)
