@@ -916,6 +916,7 @@ void pixAdvancedDialog::setDefaultTimeoutValue(const QString &option)
     string vers="version_"+obj->getStr("version");
 
     if (option=="uauth_abs" || option=="uauth_inact")
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
         data.setWidgetValue(option.toAscii().constData(),
                         Resources::platform_res[platform]->getResourceBool(
      "/FWBuilderResources/Target/options/"+vers+"/timeouts/"+option.toLatin1().constData()));
@@ -923,6 +924,15 @@ void pixAdvancedDialog::setDefaultTimeoutValue(const QString &option)
         data.setWidgetValue(option.toAscii().constData(),
                         Resources::platform_res[platform]->getResourceInt(
      "/FWBuilderResources/Target/options/"+vers+"/timeouts/"+option.toLatin1().constData()));
+#else
+        data.setWidgetValue(option.toLatin1().constData(),
+                        Resources::platform_res[platform]->getResourceBool(
+     "/FWBuilderResources/Target/options/"+vers+"/timeouts/"+option.toLatin1().constData()));
+    else
+        data.setWidgetValue(option.toLatin1().constData(),
+                        Resources::platform_res[platform]->getResourceInt(
+     "/FWBuilderResources/Target/options/"+vers+"/timeouts/"+option.toLatin1().constData()));
+#endif
 }
 
 void pixAdvancedDialog::defaultTimeouts()
