@@ -248,8 +248,13 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
 	if (platform=="pix" || platform=="fwsm")
         {
             string vers="version_"+p->getStr("version");
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
             if ( Resources::platform_res[platform.toAscii().constData()]->getResourceBool(
                   "/FWBuilderResources/Target/options/"+vers+"/pix_rule_syslog_settings"))
+#else
+            if ( Resources::platform_res[platform.toLatin1().constData()]->getResourceBool(
+                  "/FWBuilderResources/Target/options/"+vers+"/pix_rule_syslog_settings"))
+#endif
             {
                 res= ( opt->getStr("log_level").empty()        &&
                    opt->getInt("log_interval")<=0          &&
@@ -433,18 +438,27 @@ void getVersionsForPlatform(const QString &platform, std::list<QStringPair> &res
         res.push_back(QStringPair("1.4.1.1", QObject::tr("1.4.1.1 or later")));
         res.push_back(QStringPair("1.4.3", QObject::tr("1.4.3")));
         res.push_back(QStringPair("1.4.4", QObject::tr("1.4.4 or later")));
+        res.push_back(QStringPair("1.4.11", QObject::tr("1.4.11 or later")));
+        res.push_back(QStringPair("1.4.20", QObject::tr("1.4.20 or later")));
     } else
     {
         // we list supported versions for the following platforms in
         // corresponding resource .xml file
         if (platform=="pix" ||
             platform=="fwsm" ||
+            platform=="nxosacl" ||
             platform=="iosacl" ||
             platform=="procurve_acl")
         {
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
             QString lst = Resources::platform_res[
                 platform.toAscii().constData()]->getResourceStr(
                     "/FWBuilderResources/Target/versions").c_str();
+#else
+            QString lst = Resources::platform_res[
+                platform.toLatin1().constData()]->getResourceStr(
+                    "/FWBuilderResources/Target/versions").c_str();
+#endif
 
             QStringList ll=lst.split(',');
 
