@@ -355,6 +355,10 @@ QString CompilerDriver_ipfw::run(const std::string &cluster_id,
             abort(err.arg(fw_file.fileName())
                   .arg(fw_file.error()).arg(QDir::current().path()).toStdString());
         }
+
+        if (!all_errors.isEmpty())
+            status = BaseCompiler::FWCOMPILER_WARNING;
+
     }
     catch (FWException &ex)
     {
