@@ -39,23 +39,9 @@
 #include "fwbuilder/IPv4.h"
 #include "fwbuilder/Firewall.h"
 
-
-#include <iostream>
-#if __GNUC__ > 3 || \
-    (__GNUC__ == 3 && (__GNUC_MINOR__ > 2 || (__GNUC_MINOR__ == 2 ) ) ) || \
-    _MSC_VER
-#  include <streambuf>
-#else
-#  include <streambuf.h>
-#endif
-#include <iomanip>
-#include <fstream>
-#include <sstream>
-
 #include <assert.h>
 
 using namespace libfwbuilder;
 using namespace fwcompiler;
 using namespace std;
 
-
