@@ -26,17 +26,19 @@
 #include "config.h"
 
 #include "PolicyCompiler_ipf.h"
+#include "fwcompiler/Compiler.h"
 
+#include "fwbuilder/AddressTable.h"
 #include "fwbuilder/FWObjectDatabase.h"
-#include "fwbuilder/RuleElement.h"
-#include "fwbuilder/IPService.h"
+#include "fwbuilder/Firewall.h"
 #include "fwbuilder/ICMPService.h"
+#include "fwbuilder/IPService.h"
+#include "fwbuilder/Interface.h"
+#include "fwbuilder/Library.h"
+#include "fwbuilder/Policy.h"
+#include "fwbuilder/RuleElement.h"
 #include "fwbuilder/TCPService.h"
 #include "fwbuilder/UDPService.h"
-#include "fwbuilder/Policy.h"
-#include "fwbuilder/Interface.h"
-#include "fwbuilder/Firewall.h"
-#include "fwbuilder/AddressTable.h"
 
 #include <iostream>
 
@@ -54,15 +56,15 @@ int PolicyCompiler_ipf::prolog()
 
     anytcp = dbcopy->createTCPService();
     anytcp->setId(FWObjectDatabase::generateUniqueId()); //ANY_TCP_OBJ_ID);
-    dbcopy->add(anytcp,false);
+    persistent_objects->add(anytcp,false);
 
     anyudp=dbcopy->createUDPService();
     anyudp->setId(FWObjectDatabase::generateUniqueId()); //ANY_UDP_OBJ_ID);
-    dbcopy->add(anyudp,false);
+    persistent_objects->add(anyudp,false);
 
     anyicmp=dbcopy->createICMPService();
     anyicmp->setId(FWObjectDatabase::generateUniqueId()); //ANY_ICMP_OBJ_ID);
-    dbcopy->add(anyicmp,false);
+    persistent_objects->add(anyicmp,false);
 
     return n;
 }
@@ -420,87 +422,26 @@ void PolicyCompiler_ipf::compile()
 {
     info(" Compiling policy for " + fw->getName());
 
-    try {
+    Compiler::compile();
 
-	Compiler::compile();
+    bool check_for_recursive_groups=true;
 
-	addDefaultPolicyRule();
-        bool check_for_recursive_groups=true;
-
-        if ( fw->getOptionsObject()->getBool ("check_shading") &&
-             ! inSingleRuleCompileMode())
-        {
-            add( new Begin ("Detecting rule shadowing"              ) );
-            add( new printTotalNumberOfRules( ) );
-
-            add( new ItfNegation("process negation in Itf"  ) );
-            add( new InterfacePolicyRules(
-                     "process interface policy rules and store interface ids"));
-
-            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
-            add( new recursiveGroupsInDst("check for recursive groups in DST"));
-            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
-            check_for_recursive_groups=false;
-
-            add( new ExpandGroups("expand groups") );
-            add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
-            add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
-            add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
-
-            add( new swapMultiAddressObjectsInSrc(
-                     " swap MultiAddress -> MultiAddressRunTime in Src") );
-            add( new swapMultiAddressObjectsInDst(
-                     " swap MultiAddress -> MultiAddressRunTime in Dst") );
-
-            add( new ExpandMultipleAddressesInSrc(
-                     "expand objects with multiple addresses in SRC" ) );
-            add( new ExpandMultipleAddressesInDst(
-                     "expand objects with multiple addresses in DST" ) );
-            add( new ConvertToAtomic("convert to atomic rules" ) );
-
-            add( new checkForObjectsWithErrors(
-                     "check if we have objects with errors in rule elements"));
-
-            add( new DetectShadowing("Detect shadowing" ) );
-            add( new simplePrintProgress() );
-
-            runRuleProcessors();
-            deleteRuleProcessors();
-        }
-
-
-        add( new Begin());
-        add( new printTotalNumberOfRules() );
-
-        add( new singleRuleFilter());
-
-//        add( new MACFiltering(                "verify for MAC address filtering"                ) );
-        add( new setQuickFlag("set 'quick' flag") );
-
-        if (check_for_recursive_groups)
-        {
-            add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
-            add( new recursiveGroupsInDst("check for recursive groups in DST"));
-            add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
-        }
-
-        add( new emptyGroupsInSrc("check for empty groups in SRC") );
-        add( new emptyGroupsInDst("check for empty groups in DST") );
-        add( new emptyGroupsInSrv("check for empty groups in SRV") );
+    if ( fw->getOptionsObject()->getBool ("check_shading") &&
+         ! inSingleRuleCompileMode())
+    {
+        add( new Begin ("Detecting rule shadowing"              ) );
+        add( new printTotalNumberOfRules( ) );
 
         add( new ItfNegation("process negation in Itf"  ) );
         add( new InterfacePolicyRules(
-                 "process interface policy rules and store interface ids") );
+                 "process interface policy rules and store interface ids"));
 
-        add( new doSrcNegation("process negation in Src") );
-        add( new doDstNegation("process negation in Dst") );
-        add( new doSrvNegation("process negation in Srv") );
-        add( new ExpandGroups( "expand groups") );
+        add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+        add( new recursiveGroupsInDst("check for recursive groups in DST"));
+        add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
+        check_for_recursive_groups=false;
 
-        add( new CheckForTCPEstablished(
-                 "check for TCPService objects with flag \"established\"") );
-        add( new CheckForUnsupportedUserService("check for user service") );
-            
+        add( new ExpandGroups("expand groups") );
         add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
         add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
         add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
@@ -510,66 +451,117 @@ void PolicyCompiler_ipf::compile()
         add( new swapMultiAddressObjectsInDst(
                  " swap MultiAddress -> MultiAddressRunTime in Dst") );
 
-        add( new processMultiAddressObjectsInSrc(
-                 "process MultiAddress objects in Src") );
-        add( new processMultiAddressObjectsInDst(
-                 "process MultiAddress objects in Dst") );
-
-        add( new splitIfFirewallInSrc("split rule if firewall is in Src") );
-        add( new splitIfFirewallInDst("split rule if firewall is in Dst") );
-        add( new fillDirection("determine directions") );
-        add( new SplitDirectionIpfilter("split rules with direction 'both'" ) );
-        add( new ExpandMultipleAddresses(
-                 "expand objects with multiple addresses") );
-        add( new checkForDynamicInterfacesOfOtherObjects(
-                 "check for dynamic interfaces of other hosts and firewalls" ));
-        add( new MACFiltering("verify for MAC address filtering" ) );
-        add( new checkForUnnumbered("check for unnumbered interfaces") );
-        add( new specialCaseWithDynInterface(
-                 "check for a special cases with dynamic interface") );
-        add( new addressRanges("expand address range objects") );
-        add( new splitServices("split rules with different protocols") );
-        add( new separateTCPWithFlags("separate TCP services with flags" ) );
-        add( new separateSrcPort("split on TCP and UDP with source ports"));
-        add( new verifyCustomServices(
-                 "verify custom services for this platform") );
-        add( new SpecialServices("check for special services" ) );
-        add( new expandAnyService("expand ANY service for stateful rules") );
-/*
- * it may make sense to do optimization even before we expand groups
- * (before ExpandGroups). Need to test this idea.
- */
-        if ( fw->getOptionsObject()->getBool ("optimize") )
-        {
-            add( new optimizeSrc("optimization in SRC") );
-            add( new optimizeDst("optimization in DST") );
-            add( new optimizeSrv("optimization in SRV") );
-        }
-
-        add( new ConvertToAtomic("convert to atomic rules") );
-        add( new checkForZeroAddr("check for zero addresses" ) );
-
-        if ( fw->getOptionsObject()->getBool ("eliminate_duplicates") ) 
-            add( new eliminateDuplicateRules("eliminate duplicate rules" ) );
-
-	add( new calculateSkip("calculate argument for skip") );
-        add( new checkForKeepState("check for 'keep state'") );
-        add( new convertInterfaceIdToStr("prepare interface assignments") );
+        add( new ExpandMultipleAddressesInSrc(
+                 "expand objects with multiple addresses in SRC" ) );
+        add( new ExpandMultipleAddressesInDst(
+                 "expand objects with multiple addresses in DST" ) );
+        add( new ConvertToAtomic("convert to atomic rules" ) );
 
         add( new checkForObjectsWithErrors(
                  "check if we have objects with errors in rule elements"));
 
-        add( new PrintRule("generate ipf code") );
+        add( new DetectShadowing("Detect shadowing" ) );
         add( new simplePrintProgress() );
 
         runRuleProcessors();
-
-
-    } catch (FWException &ex)
-    {
-	error(ex.toString());
-	exit(1);
+        deleteRuleProcessors();
     }
+
+
+    add( new Begin());
+    add( new printTotalNumberOfRules() );
+
+    add( new singleRuleFilter());
+
+//        add( new MACFiltering(                "verify for MAC address filtering"                ) );
+    add( new setQuickFlag("set 'quick' flag") );
+
+    if (check_for_recursive_groups)
+    {
+        add( new recursiveGroupsInSrc("check for recursive groups in SRC"));
+        add( new recursiveGroupsInDst("check for recursive groups in DST"));
+        add( new recursiveGroupsInSrv("check for recursive groups in SRV"));
+    }
+
+    add( new emptyGroupsInSrc("check for empty groups in SRC") );
+    add( new emptyGroupsInDst("check for empty groups in DST") );
+    add( new emptyGroupsInSrv("check for empty groups in SRV") );
+
+    add( new ItfNegation("process negation in Itf"  ) );
+    add( new InterfacePolicyRules(
+             "process interface policy rules and store interface ids") );
+
+    add( new doSrcNegation("process negation in Src") );
+    add( new doDstNegation("process negation in Dst") );
+    add( new doSrvNegation("process negation in Srv") );
+    add( new ExpandGroups( "expand groups") );
+
+    add( new CheckForTCPEstablished(
+             "check for TCPService objects with flag \"established\"") );
+    add( new CheckForUnsupportedUserService("check for user service") );
+            
+    add( new eliminateDuplicatesInSRC("eliminate duplicates in SRC") );
+    add( new eliminateDuplicatesInDST("eliminate duplicates in DST") );
+    add( new eliminateDuplicatesInSRV("eliminate duplicates in SRV") );
+
+    add( new swapMultiAddressObjectsInSrc(
+             " swap MultiAddress -> MultiAddressRunTime in Src") );
+    add( new swapMultiAddressObjectsInDst(
+             " swap MultiAddress -> MultiAddressRunTime in Dst") );
+
+    add( new processMultiAddressObjectsInSrc(
+             "process MultiAddress objects in Src") );
+    add( new processMultiAddressObjectsInDst(
+             "process MultiAddress objects in Dst") );
+
+    add( new splitIfFirewallInSrc("split rule if firewall is in Src") );
+    add( new splitIfFirewallInDst("split rule if firewall is in Dst") );
+    add( new fillDirection("determine directions") );
+    add( new SplitDirectionIpfilter("split rules with direction 'both'" ) );
+    add( new ExpandMultipleAddresses(
+             "expand objects with multiple addresses") );
+    add( new checkForDynamicInterfacesOfOtherObjects(
+             "check for dynamic interfaces of other hosts and firewalls" ));
+    add( new MACFiltering("verify for MAC address filtering" ) );
+    add( new checkForUnnumbered("check for unnumbered interfaces") );
+    add( new specialCaseWithDynInterface(
+             "check for a special cases with dynamic interface") );
+    add( new addressRanges("expand address range objects") );
+    add( new groupServicesByProtocol("split rules with different protocols") );
+    add( new separateTCPWithFlags("separate TCP services with flags" ) );
+    add( new separateSrcPort("split on TCP and UDP with source ports"));
+    add( new verifyCustomServices(
+             "verify custom services for this platform") );
+    add( new SpecialServices("check for special services" ) );
+    add( new expandAnyService("expand ANY service for stateful rules") );
+/*
+ * it may make sense to do optimization even before we expand groups
+ * (before ExpandGroups). Need to test this idea.
+ */
+    if ( fw->getOptionsObject()->getBool ("optimize") )
+    {
+        add( new optimizeSrc("optimization in SRC") );
+        add( new optimizeDst("optimization in DST") );
+        add( new optimizeSrv("optimization in SRV") );
+    }
+
+    add( new ConvertToAtomic("convert to atomic rules") );
+    add( new checkForZeroAddr("check for zero addresses" ) );
+
+    if ( fw->getOptionsObject()->getBool ("eliminate_duplicates") ) 
+        add( new eliminateDuplicateRules("eliminate duplicate rules" ) );
+
+    add( new calculateSkip("calculate argument for skip") );
+    add( new checkForKeepState("check for 'keep state'") );
+
+    add( new checkForObjectsWithErrors(
+             "check if we have objects with errors in rule elements"));
+
+    add( new PrintRule("generate ipf code") );
+    add( new simplePrintProgress() );
+
+    runRuleProcessors();
+
 }
 
 string PolicyCompiler_ipf::debugPrintRule(Rule *r)
@@ -600,14 +592,6 @@ string PolicyCompiler_ipf::debugPrintRule(Rule *r)
     else
         s << " intf: ?";
 
-    // int iface_id = rule->getInterfaceId();
-    // if (iface_id > -1)
-    // {
-    //     FWObject *rule_iface = dbcopy->findInIndex( iface_id );
-    //     s << " intf: "+rule_iface->getName();
-    // } else
-    //     s << iface_id;
-
     s << " ";
 
     if (r->getBool("skip_check_for_duplicates")) s << "skip_check_for_duplicates ";
