@@ -31,7 +31,6 @@
 #include "FWWindow.h"
 #include "FWBSettings.h"
 #include "FWBApplication.h"
-#include "UserWorkflow.h"
 
 #include <QApplication>
 #include <QString>
@@ -44,7 +43,6 @@ int fwbdebug = 0;
 FWWindow *mw = NULL; 
 FWBSettings *st = NULL; 
 FWBApplication *app = NULL; 
-UserWorkflow *wfl; 
 int sig = FWB_SIG; 
 std::string platform;
 
